@@ -11,7 +11,7 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "common/os.h"
+#include "common/common_pch.h"
 
 #include <algorithm>
 
@@ -22,7 +22,6 @@
 #include <matroska/KaxSeekHead.h>
 #include <matroska/KaxSegment.h>
 
-#include "common/common.h"
 #include "common/ebml.h"
 #include "common/error.h"
 #include "common/kax_analyzer.h"
@@ -43,18 +42,18 @@ operator <(const kax_analyzer_data_cptr &d1,
 
 std::string
 kax_analyzer_data_c::to_string() const {
-  const EbmlCallbacks *callbacks = find_ebml_callbacks(KaxSegment::ClassInfos, m_id);
+  const EbmlCallbacks *callbacks = find_ebml_callbacks(EBML_INFO(KaxSegment), m_id);
 
-  if ((NULL == callbacks) && (EbmlVoid::ClassInfos.GlobalId == m_id))
-    callbacks = &EbmlVoid::ClassInfos;
+  if ((NULL == callbacks) && (EBML_ID(EbmlVoid) == m_id))
+    callbacks = &EBML_INFO(EbmlVoid);
 
   std::string name;
   if (NULL != callbacks)
-    name = callbacks->DebugName;
+    name = EBML_INFO_NAME(*callbacks);
 
   else {
-    std::string format = (boost::format("0x%%|0%1%x|") % (m_id.Length * 2)).str();
-    name               = (boost::format(format)        %  m_id.Value).str();
+    std::string format = (boost::format("0x%%|0%1%x|") % (EBML_ID_LENGTH(m_id) * 2)).str();
+    name               = (boost::format(format)        %  EBML_ID_VALUE(m_id)).str();
   }
 
   return (boost::format("%1% size %2% at %3%") % name % m_size % m_pos).str();
@@ -203,24 +202,24 @@ kax_analyzer_c::process(kax_analyzer_c::parse_mode_e parse_mode,
   m_stream = new EbmlStream(*m_file);
 
   // Find the EbmlHead element. Must be the first one.
-  EbmlElement *l0 = m_stream->FindNextID(EbmlHead::ClassInfos, 0xFFFFFFFFL);
+  EbmlElement *l0 = m_stream->FindNextID(EBML_INFO(EbmlHead), 0xFFFFFFFFL);
   if (NULL == l0)
     throw error_c(Y("Not a valid Matroska file (no EBML head found)"));
 
   // Don't verify its data for now.
-  l0->SkipData(*m_stream, l0->Generic().Context);
+  l0->SkipData(*m_stream, EBML_CONTEXT(l0));
   delete l0;
 
   while (1) {
     // Next element must be a segment
-    l0 = m_stream->FindNextID(KaxSegment::ClassInfos, 0xFFFFFFFFFFFFFFFFLL);
+    l0 = m_stream->FindNextID(EBML_INFO(KaxSegment), 0xFFFFFFFFFFFFFFFFLL);
     if (NULL == l0)
       throw error_c(Y("Not a valid Matroska file (no segment/level 0 element found)"));
 
-    if (EbmlId(*l0) == KaxSegment::ClassInfos.GlobalId)
+    if (EbmlId(*l0) == EBML_ID(KaxSegment))
       break;
 
-    l0->SkipData(*m_stream, l0->Generic().Context);
+    l0->SkipData(*m_stream, EBML_CONTEXT(l0));
     delete l0;
   }
 
@@ -231,14 +230,14 @@ kax_analyzer_c::process(kax_analyzer_c::parse_mode_e parse_mode,
   bool meta_seek_found = false;
 
   // We've got our segment, so let's find all level 1 elements.
-  EbmlElement *l1 = m_stream->FindNextElement(m_segment->Generic().Context, upper_lvl_el, 0xFFFFFFFFFFFFFFFFLL, true, 1);
+  EbmlElement *l1 = m_stream->FindNextElement(EBML_CONTEXT(m_segment), upper_lvl_el, 0xFFFFFFFFFFFFFFFFLL, true, 1);
   while ((NULL != l1) && (0 >= upper_lvl_el)) {
-    m_data.push_back(kax_analyzer_data_c::create(l1->Generic().GlobalId, l1->GetElementPosition(), l1->ElementSize(true)));
+    m_data.push_back(kax_analyzer_data_c::create(EbmlId(*l1), l1->GetElementPosition(), l1->ElementSize(true)));
 
     cluster_found   |= is_id(l1, KaxCluster);
     meta_seek_found |= is_id(l1, KaxSeekHead);
 
-    l1->SkipData(*m_stream, l1->Generic().Context);
+    l1->SkipData(*m_stream, EBML_CONTEXT(l1));
     delete l1;
     l1 = NULL;
 
@@ -247,7 +246,7 @@ kax_analyzer_c::process(kax_analyzer_c::parse_mode_e parse_mode,
     if (!in_parent(m_segment) || aborted || (cluster_found && meta_seek_found && !parse_fully))
       break;
 
-    l1 = m_stream->FindNextElement(m_segment->Generic().Context, upper_lvl_el, 0xFFFFFFFFL, true);
+    l1 = m_stream->FindNextElement(EBML_CONTEXT(m_segment), upper_lvl_el, 0xFFFFFFFFL, true);
   } // while (l1 != NULL)
 
   if (NULL != l1)
@@ -277,16 +276,16 @@ kax_analyzer_c::read_element(kax_analyzer_data_c *element_data) {
   m_file->setFilePointer(element_data->m_pos);
 
   int upper_lvl_el               = 0;
-  EbmlElement *e                 = es.FindNextElement(m_segment->Generic().Context, upper_lvl_el, 0xFFFFFFFFL, true, 1);
-  const EbmlCallbacks *callbacks = find_ebml_callbacks(KaxSegment::ClassInfos, element_data->m_id);
+  EbmlElement *e                 = es.FindNextElement(EBML_CONTEXT(m_segment), upper_lvl_el, 0xFFFFFFFFL, true, 1);
+  const EbmlCallbacks *callbacks = find_ebml_callbacks(EBML_INFO(KaxSegment), element_data->m_id);
 
-  if ((NULL == e) || (NULL == callbacks) || (EbmlId(*e) != callbacks->GlobalId)) {
+  if ((NULL == e) || (NULL == callbacks) || (EbmlId(*e) != EBML_INFO_ID(*callbacks))) {
     delete e;
     return NULL;
   }
 
   upper_lvl_el = 0;
-  e->Read(*m_stream, callbacks->Context, upper_lvl_el, e, true);
+  e->Read(*m_stream, EBML_INFO_CONTEXT(*callbacks), upper_lvl_el, e, true);
 
   return e;
 }
@@ -306,14 +305,14 @@ kax_analyzer_c::update_element(EbmlElement *e,
   fix_mandatory_elements(e);
 
   try {
-    call_and_validate({},                                             "update_element_0");
-    call_and_validate(overwrite_all_instances(e->Generic().GlobalId), "update_element_1");
-    call_and_validate(merge_void_elements(),                          "update_element_2");
-    call_and_validate(write_element(e, write_defaults),               "update_element_3");
-    call_and_validate(remove_from_meta_seeks(e->Generic().GlobalId),  "update_element_4");
-    call_and_validate(merge_void_elements(),                          "update_element_5");
-    call_and_validate(add_to_meta_seek(e),                            "update_element_6");
-    call_and_validate(merge_void_elements(),                          "update_element_7");
+    call_and_validate({},                                 "update_element_0");
+    call_and_validate(overwrite_all_instances(EbmlId(*e)), "update_element_1");
+    call_and_validate(merge_void_elements(),               "update_element_2");
+    call_and_validate(write_element(e, write_defaults),    "update_element_3");
+    call_and_validate(remove_from_meta_seeks(EbmlId(*e)),  "update_element_4");
+    call_and_validate(merge_void_elements(),               "update_element_5");
+    call_and_validate(add_to_meta_seek(e),                 "update_element_6");
+    call_and_validate(merge_void_elements(),               "update_element_7");
 
   } catch (kax_analyzer_c::update_element_result_e result) {
     debug_dump_elements_maybe("update_element_exception");
@@ -413,7 +412,7 @@ kax_analyzer_c::handle_void_elements(int data_idx) {
 
   // Are the following elements EbmlVoid elements?
   int end_idx = data_idx + 1;
-  while ((m_data.size() > end_idx) && (m_data[end_idx]->m_id == EbmlVoid::ClassInfos.GlobalId))
+  while ((m_data.size() > end_idx) && (m_data[end_idx]->m_id == EBML_ID(EbmlVoid)))
     ++end_idx;
 
   if (end_idx > data_idx + 1)
@@ -447,7 +446,7 @@ kax_analyzer_c::handle_void_elements(int data_idx) {
       return false;
 
     binary head[4 + 8];         // Class D + 64 bits coded size
-    unsigned int head_size = EbmlId(*e).Length;
+    unsigned int head_size = EBML_ID_LENGTH(EbmlId(*e));
     EbmlId(*e).Fill(head);
 
     int coded_size = CodedSizeLength(e->GetSize(), e->GetSizeLength() + 1, true);
@@ -465,7 +464,7 @@ kax_analyzer_c::handle_void_elements(int data_idx) {
     // Update meta seek indices for m_data[data_idx]'s new position.
     e = read_element(m_data[data_idx + 1]);
 
-    remove_from_meta_seeks(e->Generic().GlobalId);
+    remove_from_meta_seeks(EbmlId(*e));
     merge_void_elements();
     add_to_meta_seek(e);
     merge_void_elements();
@@ -484,7 +483,7 @@ kax_analyzer_c::handle_void_elements(int data_idx) {
   evoid.SetSize(void_size - evoid.HeadSize());
   evoid.Render(*m_file);
 
-  m_data.insert(m_data.begin() + data_idx + 1, kax_analyzer_data_c::create(EbmlVoid::ClassInfos.GlobalId, void_pos, void_size));
+  m_data.insert(m_data.begin() + data_idx + 1, kax_analyzer_data_c::create(EBML_ID(EbmlVoid), void_pos, void_size));
 
   // Now check if we should overwrite the current element with the
   // EbmlVoid element. That is the case if the current element's size
@@ -512,7 +511,7 @@ kax_analyzer_c::remove_from_meta_seeks(EbmlId id) {
 
   for (data_idx = 0; m_data.size() > data_idx; ++data_idx) {
     // We only have to do work on SeekHead elements. Skip the others.
-    if (m_data[data_idx]->m_id != KaxSeekHead::ClassInfos.GlobalId)
+    if (m_data[data_idx]->m_id != EBML_ID(KaxSeekHead))
       continue;
 
     // Read the element from the m_file. Remember its size so that a new
@@ -528,7 +527,7 @@ kax_analyzer_c::remove_from_meta_seeks(EbmlId id) {
     bool modified = false;
     int sh_idx    = 0;
     while (seek_head->ListSize() > sh_idx) {
-      if ((*seek_head)[sh_idx]->Generic().GlobalId != KaxSeek::ClassInfos.GlobalId) {
+      if (EbmlId(*(*seek_head)[sh_idx]) != EBML_ID(KaxSeek)) {
         ++sh_idx;
         continue;
       }
@@ -609,7 +608,7 @@ kax_analyzer_c::merge_void_elements() {
 
   while (m_data.size() > start_idx) {
     // We only have to do work on EbmlVoid elements. Skip the others.
-    if (m_data[start_idx]->m_id != EbmlVoid::ClassInfos.GlobalId) {
+    if (m_data[start_idx]->m_id != EBML_ID(EbmlVoid)) {
       ++start_idx;
       continue;
     }
@@ -618,7 +617,7 @@ kax_analyzer_c::merge_void_elements() {
     // there are at this position and calculate the combined size.
     int end_idx  = start_idx + 1;
     int new_size = m_data[start_idx]->m_size;
-    while ((m_data.size() > end_idx) && (m_data[end_idx]->m_id == EbmlVoid::ClassInfos.GlobalId)) {
+    while ((m_data.size() > end_idx) && (m_data[end_idx]->m_id == EBML_ID(EbmlVoid))) {
       new_size += m_data[end_idx]->m_size;
       ++end_idx;
     }
@@ -648,7 +647,7 @@ kax_analyzer_c::merge_void_elements() {
   // See how many void elements there are at the end of the m_file.
   start_idx = m_data.size() - 1;
 
-  while ((0 <= start_idx) && (EbmlVoid::ClassInfos.GlobalId == m_data[start_idx]->m_id))
+  while ((0 <= start_idx) && (EBML_ID(EbmlVoid) == m_data[start_idx]->m_id))
     --start_idx;
   ++start_idx;
 
@@ -687,7 +686,7 @@ kax_analyzer_c::write_element(EbmlElement *e,
   int data_idx;
   for (data_idx = 0; m_data.size() > data_idx; ++data_idx) {
     // We're only interested in EbmlVoid elements. Skip the others.
-    if (m_data[data_idx]->m_id != EbmlVoid::ClassInfos.GlobalId)
+    if (m_data[data_idx]->m_id != EBML_ID(EbmlVoid))
       continue;
 
     // Skip the element if it doesn't provide enough space.
@@ -699,7 +698,7 @@ kax_analyzer_c::write_element(EbmlElement *e,
     e->Render(*m_file, write_defaults);
 
     // Update the internal records.
-    m_data[data_idx]->m_id   = e->Generic().GlobalId;
+    m_data[data_idx]->m_id   = EbmlId(*e);
     m_data[data_idx]->m_size = e->ElementSize(write_defaults);
 
     // Create a new void element after the element we've just written.
@@ -713,7 +712,7 @@ kax_analyzer_c::write_element(EbmlElement *e,
   // and update the internal records.
   m_file->setFilePointer(0, seek_end);
   e->Render(*m_file, write_defaults);
-  m_data.push_back(kax_analyzer_data_c::create(e->Generic().GlobalId, m_file->getFilePointer() - e->ElementSize(write_defaults), e->ElementSize(write_defaults)));
+  m_data.push_back(kax_analyzer_data_c::create(EbmlId(*e), m_file->getFilePointer() - e->ElementSize(write_defaults), e->ElementSize(write_defaults)));
 
   // Adjust the m_segment's size.
   adjust_segment_size();
@@ -737,7 +736,7 @@ kax_analyzer_c::add_to_meta_seek(EbmlElement *e) {
 
   for (data_idx = 0; m_data.size() > data_idx; ++data_idx) {
     // We only have to do work on SeekHead elements. Skip the others.
-    if (m_data[data_idx]->m_id != KaxSeekHead::ClassInfos.GlobalId)
+    if (m_data[data_idx]->m_id != EBML_ID(KaxSeekHead))
       continue;
 
     // Calculate how much free space there is behind the seek head.
@@ -746,7 +745,7 @@ kax_analyzer_c::add_to_meta_seek(EbmlElement *e) {
     // have been merged into a single element.
     int available_space = m_data[data_idx]->m_size;
     bool void_present   = false;
-    if (((data_idx + 1) < m_data.size()) && (m_data[data_idx + 1]->m_id == EbmlVoid::ClassInfos.GlobalId)) {
+    if (((data_idx + 1) < m_data.size()) && (m_data[data_idx + 1]->m_id == EBML_ID(EbmlVoid))) {
       available_space += m_data[data_idx + 1]->m_size;
       void_present     = true;
     }
@@ -813,7 +812,7 @@ kax_analyzer_c::add_to_meta_seek(EbmlElement *e) {
     seek_head->Render(*m_file, true);
 
     // ...and update the internal records.
-    m_data.push_back(kax_analyzer_data_c::create(KaxSeekHead::ClassInfos.GlobalId, seek_head->GetElementPosition(), seek_head->ElementSize(true)));
+    m_data.push_back(kax_analyzer_data_c::create(EBML_ID(KaxSeekHead), seek_head->GetElementPosition(), seek_head->ElementSize(true)));
 
     // Update the m_segment size.
     adjust_segment_size();
@@ -846,7 +845,7 @@ kax_analyzer_c::add_to_meta_seek(EbmlElement *e) {
 
   for (data_idx = 0; m_data.size() > data_idx; ++data_idx) {
     // We can only overwrite void elements. Skip the others.
-    if (m_data[data_idx]->m_id != EbmlVoid::ClassInfos.GlobalId)
+    if (m_data[data_idx]->m_id != EBML_ID(EbmlVoid))
       continue;
 
     // Skip the element if it doesn't offer enough space for the seek head.
@@ -859,7 +858,7 @@ kax_analyzer_c::add_to_meta_seek(EbmlElement *e) {
 
     // Adjust the internal records for the new seek head.
     m_data[data_idx]->m_size = new_seek_head->ElementSize(true);
-    m_data[data_idx]->m_id   = KaxSeekHead::ClassInfos.GlobalId;
+    m_data[data_idx]->m_id   = EBML_ID(KaxSeekHead);
 
     // Write a void element after the newly written seek head in order to
     // cover the space previously occupied by the old void element.
@@ -885,22 +884,22 @@ kax_analyzer_c::read_all(const EbmlCallbacks &callbacks) {
 
   for (i = 0; m_data.size() > i; ++i) {
     kax_analyzer_data_c &data = *m_data[i].get_object();
-    if (callbacks.GlobalId != data.m_id)
+    if (EBML_INFO_ID(callbacks) != data.m_id)
       continue;
 
     m_file->setFilePointer(data.m_pos);
     int upper_lvl_el     = 0;
-    EbmlElement *element = es.FindNextElement(KaxSegment::ClassInfos.Context, upper_lvl_el, 0xFFFFFFFFL, true);
+    EbmlElement *element = es.FindNextElement(EBML_INFO_CONTEXT(EBML_INFO(KaxSegment)), upper_lvl_el, 0xFFFFFFFFL, true);
     if (NULL == element)
       continue;
 
-    if (element->Generic().GlobalId != callbacks.GlobalId) {
+    if (EbmlId(*element) != EBML_INFO_ID(callbacks)) {
       delete element;
       continue;
     }
 
     EbmlElement *l2 = NULL;
-    element->Read(*m_stream, callbacks.Context, upper_lvl_el, l2, true);
+    element->Read(*m_stream, EBML_INFO_CONTEXT(callbacks), upper_lvl_el, l2, true);
 
     if (NULL == master)
       master = static_cast<EbmlMaster *>(element);
@@ -933,7 +932,7 @@ kax_analyzer_c::read_all_meta_seeks() {
     positions_found[m_data[i]->m_pos] = true;
 
   for (i = 0; i < num_entries; i++)
-    if (KaxSeekHead::ClassInfos.GlobalId == m_data[i]->m_id)
+    if (EBML_ID(KaxSeekHead) == m_data[i]->m_id)
       read_meta_seek(m_data[i]->m_pos, positions_found);
 
   sort(m_data.begin(), m_data.end());
@@ -950,7 +949,7 @@ kax_analyzer_c::read_meta_seek(int64_t pos,
   m_file->setFilePointer(pos, seek_beginning);
 
   int upper_lvl_el = 0;
-  EbmlElement *l1  = m_stream->FindNextElement(m_segment->Generic().Context, upper_lvl_el, 0xFFFFFFFFL, true, 1);
+  EbmlElement *l1  = m_stream->FindNextElement(EBML_CONTEXT(m_segment), upper_lvl_el, 0xFFFFFFFFL, true, 1);
 
   if (NULL == l1)
     return;
@@ -962,7 +961,7 @@ kax_analyzer_c::read_meta_seek(int64_t pos,
 
   EbmlElement *l2    = NULL;
   EbmlMaster *master = static_cast<EbmlMaster *>(l1);
-  master->Read(*m_stream, l1->Generic().Context, upper_lvl_el, l2, true);
+  master->Read(*m_stream, EBML_CONTEXT(l1), upper_lvl_el, l2, true);
 
   unsigned int i;
   for (i = 0; master->ListSize() > i; i++) {
@@ -983,7 +982,7 @@ kax_analyzer_c::read_meta_seek(int64_t pos,
     m_data.push_back(kax_analyzer_data_c::create(the_id, seek_pos, -1));
     positions_found[seek_pos] = true;
 
-    if (KaxSeekHead::ClassInfos.GlobalId == the_id)
+    if (EBML_ID(KaxSeekHead) == the_id)
       read_meta_seek(seek_pos, positions_found);
   }
 
