@@ -12,12 +12,11 @@
    Modifications by Peter Niemayer <niemayer@isg.de>.
 */
 
-#include "common/os.h"
+#include "common/common_pch.h"
 
 #include <errno.h>
 #if HAVE_POSIX_FADVISE
 # include <fcntl.h>
-# include <map>
 # include <sys/utsname.h>
 #endif
 #include <string.h>
@@ -33,11 +32,9 @@
 # include <sys/types.h>
 #endif // SYS_WINDOWS
 
-#include "common/common.h"
 #include "common/endian.h"
 #include "common/error.h"
 #include "common/fs_sys_helpers.h"
-#include "common/locale.h"
 #include "common/mm_io.h"
 #include "common/strings/editing.h"
 #include "common/strings/parsing.h"
@@ -998,7 +995,7 @@ mm_mem_io_c::~mm_mem_io_c() {
   close();
 }
 
-uint64_t
+uint64
 mm_mem_io_c::getFilePointer() {
   return pos;
 }
@@ -1106,26 +1103,46 @@ mm_text_io_c::mm_text_io_c(mm_io_c *_in,
     return;
   }
 
-  if ((3 <= num_read) && (buffer[0] == 0xef) && (buffer[1] == 0xbb) && (buffer[2] == 0xbf)) {
-    byte_order = BO_UTF8;
-    bom_len    = 3;
-  } else if ((4 <= num_read) && (buffer[0] == 0xff) && (buffer[1] == 0xfe) && (buffer[2] == 0x00) && (buffer[3] == 0x00)) {
-    byte_order = BO_UTF32_LE;
-    bom_len    = 4;
-  } else if ((4 <= num_read) && (buffer[0] == 0x00) && (buffer[1] == 0x00) && (buffer[2] == 0xfe) && (buffer[3] == 0xff)) {
-    byte_order = BO_UTF32_BE;
-    bom_len    = 4;
-  } else if ((2 <= num_read) && (buffer[0] == 0xff) && (buffer[1] == 0xfe)) {
-    byte_order = BO_UTF16_LE;
-    bom_len    = 2;
-  } else if ((2 <= num_read) && (buffer[0] == 0xfe) && (buffer[1] == 0xff)) {
-    byte_order = BO_UTF16_BE;
-    bom_len    = 2;
-  }
+  detect_byte_order_marker(buffer, num_read, byte_order, bom_len);
 
   _in->setFilePointer(bom_len, seek_beginning);
 }
 
+bool
+mm_text_io_c::detect_byte_order_marker(const unsigned char *buffer,
+                                       unsigned int size,
+                                       byte_order_e &byte_order,
+                                       unsigned int &bom_length) {
+  if ((3 <= size) && (buffer[0] == 0xef) && (buffer[1] == 0xbb) && (buffer[2] == 0xbf)) {
+    byte_order = BO_UTF8;
+    bom_length = 3;
+  } else if ((4 <= size) && (buffer[0] == 0xff) && (buffer[1] == 0xfe) && (buffer[2] == 0x00) && (buffer[3] == 0x00)) {
+    byte_order = BO_UTF32_LE;
+    bom_length = 4;
+  } else if ((4 <= size) && (buffer[0] == 0x00) && (buffer[1] == 0x00) && (buffer[2] == 0xfe) && (buffer[3] == 0xff)) {
+    byte_order = BO_UTF32_BE;
+    bom_length = 4;
+  } else if ((2 <= size) && (buffer[0] == 0xff) && (buffer[1] == 0xfe)) {
+    byte_order = BO_UTF16_LE;
+    bom_length = 2;
+  } else if ((2 <= size) && (buffer[0] == 0xfe) && (buffer[1] == 0xff)) {
+    byte_order = BO_UTF16_BE;
+    bom_length = 2;
+  } else {
+    byte_order = BO_NONE;
+    bom_length = 0;
+  }
+
+  return BO_NONE != byte_order;
+}
+
+bool
+mm_text_io_c::has_byte_order_marker(const std::string &string) {
+  byte_order_e byte_order;
+  unsigned int bom_length;
+  return detect_byte_order_marker(reinterpret_cast<const unsigned char *>(string.c_str()), string.length(), byte_order, bom_length);
+}
+
 // 1 byte: 0xxxxxxx,
 // 2 bytes: 110xxxxx 10xxxxxx,
 // 3 bytes: 1110xxxx 10xxxxxx 10xxxxxx
@@ -1206,26 +1223,40 @@ mm_text_io_c::read_next_char(char *buffer) {
 
 std::string
 mm_text_io_c::getline() {
-  std::string s;
-  char utf8char[8];
-
   if (eof())
     throw error_c(Y("end-of-file"));
 
+  std::string s;
+  char utf8char[9];
+  bool previous_was_carriage_return = false;
+
   while (1) {
-    memset(utf8char, 0, 8);
+    memset(utf8char, 0, 9);
 
     int len = read_next_char(utf8char);
     if (0 == len)
       return s;
 
-    if ((1 == len) && (utf8char[0] == '\r'))
+    if ((1 == len) && (utf8char[0] == '\r')) {
+      if (previous_was_carriage_return) {
+        setFilePointer(-1, seek_current);
+        return s;
+      }
+
+      previous_was_carriage_return = true;
       continue;
+    }
 
     if ((1 == len) && (utf8char[0] == '\n'))
       return s;
 
-    s += utf8char;
+    if (previous_was_carriage_return) {
+      setFilePointer(-len, seek_current);
+      return s;
+    }
+
+    previous_was_carriage_return  = false;
+    s                            += utf8char;
   }
 }
 
@@ -1237,7 +1268,7 @@ mm_text_io_c::get_byte_order() {
 void
 mm_text_io_c::setFilePointer(int64 offset,
                              seek_mode mode) {
-  mm_proxy_io_c::setFilePointer(((0 == offset) && (seek_beginning == mode)) ? bom_len : offset, seek_beginning);
+  mm_proxy_io_c::setFilePointer(((0 == offset) && (seek_beginning == mode)) ? bom_len : offset, mode);
 }
 
 /*
