@@ -11,27 +11,29 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __MM_IO_H
-#define __MM_IO_H
+#ifndef __MTX_COMMON_MM_IO_H
+#define __MTX_COMMON_MM_IO_H
 
-#include "os.h"
+#include "common/common_pch.h"
 
-#include <string>
 #include <stack>
-#include <vector>
+#if HAVE_POSIX_FADVISE
+# include <unistd.h>
+# include <sys/stat.h>
+# include <sys/types.h>
+#endif
 
 #include <ebml/IOCallback.h>
 
-#include "common_memory.h"
-#include "error.h"
-#include "smart_pointers.h"
+#include "common/error.h"
+#include "common/memory.h"
+#include "common/smart_pointers.h"
 
-using namespace std;
 using namespace libebml;
 
 class MTX_DLL_API mm_io_error_c: public error_c {
 public:
-  mm_io_error_c(const string &_error): error_c(_error) { }
+  mm_io_error_c(const std::string &_error): error_c(_error) { }
 };
 
 class MTX_DLL_API mm_io_eof_error_c: public mm_io_error_c {
@@ -52,22 +54,23 @@ public:
 class MTX_DLL_API mm_io_c: public IOCallback {
 protected:
   bool dos_style_newlines;
-  stack<int64_t> positions;
+  std::stack<int64_t> positions;
   int64_t m_current_position, cached_size;
 
 public:
-  mm_io_c():
-    dos_style_newlines(false),
-    m_current_position(0), cached_size(-1) {
+  mm_io_c()
+    : dos_style_newlines(false)
+    , m_current_position(0)
+    , cached_size(-1)
+  {
   }
   virtual ~mm_io_c() { }
 
   virtual uint64 getFilePointer() = 0;
-  virtual void setFilePointer(int64 offset, seek_mode mode = seek_beginning)
-    = 0;
+  virtual void setFilePointer(int64 offset, seek_mode mode = seek_beginning) = 0;
   virtual bool setFilePointer2(int64 offset, seek_mode mode = seek_beginning);
   virtual uint32 read(void *buffer, size_t size) = 0;
-  virtual uint32_t read(string &buffer, size_t size);
+  virtual uint32_t read(std::string &buffer, size_t size);
   virtual uint32_t read(memory_cptr &buffer, size_t size, int offset = 0);
   virtual unsigned char read_uint8();
   virtual uint16_t read_uint16_le();
@@ -92,15 +95,15 @@ public:
   virtual void flush() {
   }
 
-  virtual string get_file_name() const = 0;
+  virtual std::string get_file_name() const = 0;
 
-  virtual string getline();
-  virtual bool getline2(string &s);
-  virtual size_t puts(const string &s);
+  virtual std::string getline();
+  virtual bool getline2(std::string &s);
+  virtual size_t puts(const std::string &s);
   inline size_t puts(const boost::format &format) {
     return puts(format.str());
   }
-  virtual bool write_bom(const string &charset);
+  virtual bool write_bom(const std::string &charset);
   virtual int getch();
 
   virtual void save_pos(int64_t new_pos = -1);
@@ -117,24 +120,47 @@ public:
 
 typedef counted_ptr<mm_io_c> mm_io_cptr;
 
+#if HAVE_POSIX_FADVISE
+struct file_id_t {
+  bool m_initialized;
+  dev_t m_dev;
+  ino_t m_ino;
+
+  file_id_t()
+    : m_initialized(false)
+    , m_dev(0)
+    , m_ino(0)
+  {
+  }
+
+  void initialize(const struct stat &st) {
+    m_dev         = st.st_dev;
+    m_ino         = st.st_ino;
+    m_initialized = true;
+  }
+};
+#endif
+
 class MTX_DLL_API mm_file_io_c: public mm_io_c {
 protected:
 #if defined(SYS_WINDOWS)
   bool _eof;
 #endif
 #if HAVE_POSIX_FADVISE
+  file_id_t m_file_id;
   unsigned long read_count, write_count;
   static bool use_posix_fadvise;
   bool use_posix_fadvise_here;
+  std::string canonicalized_file_name;
 #endif
-  string file_name;
+  std::string file_name;
   void *file;
 
 public:
-  mm_file_io_c(const string &path, const open_mode mode = MODE_READ);
+  mm_file_io_c(const std::string &path, const open_mode mode = MODE_READ);
   virtual ~mm_file_io_c();
 
-  static void prepare_path(const string &path);
+  static void prepare_path(const std::string &path);
 
   virtual uint64 getFilePointer();
 #if defined(SYS_WINDOWS)
@@ -146,13 +172,18 @@ public:
   virtual void close();
   virtual bool eof();
 
-  virtual string get_file_name() const {
+  virtual std::string get_file_name() const {
     return file_name;
   }
 
   virtual int truncate(int64_t pos);
 
+#if HAVE_POSIX_FADVISE
+  void setup_fadvise(const std::string &local_path);
+#endif
+
   static void setup();
+  static void cleanup();
 };
 
 typedef counted_ptr<mm_file_io_c> mm_file_io_cptr;
@@ -187,7 +218,7 @@ public:
     return proxy_io->eof();
   }
   virtual void close();
-  virtual string get_file_name() const {
+  virtual std::string get_file_name() const {
     return proxy_io->get_file_name();
   }
 };
@@ -216,7 +247,7 @@ protected:
   unsigned char *mem;
   const unsigned char *ro_mem;
   bool free_mem, read_only;
-  string file_name;
+  std::string file_name;
 
 public:
   mm_mem_io_c(unsigned char *_mem, uint64_t _mem_size, int _increase);
@@ -235,10 +266,10 @@ public:
   }
   virtual void close();
   virtual bool eof();
-  virtual string get_file_name() const {
+  virtual std::string get_file_name() const {
     return file_name;
   }
-  virtual void set_file_name(const string &_file_name) {
+  virtual void set_file_name(const std::string &_file_name) {
     file_name = _file_name;
   }
 
@@ -252,18 +283,22 @@ enum byte_order_e {BO_UTF8, BO_UTF16_LE, BO_UTF16_BE, BO_UTF32_LE, BO_UTF32_BE,
 class MTX_DLL_API mm_text_io_c: public mm_proxy_io_c {
 protected:
   byte_order_e byte_order;
-  int bom_len;
+  unsigned int bom_len;
 
 public:
   mm_text_io_c(mm_io_c *_in, bool _delete_in = true);
 
   virtual void setFilePointer(int64 offset, seek_mode mode=seek_beginning);
-  virtual string getline();
+  virtual std::string getline();
   virtual int read_next_char(char *buffer);
   virtual byte_order_e get_byte_order();
   virtual void set_byte_order(byte_order_e new_byte_order) {
     byte_order = new_byte_order;
   }
+
+public:
+  static bool has_byte_order_marker(const std::string &string);
+  static bool detect_byte_order_marker(const unsigned char *buffer, unsigned int size, byte_order_e &byte_order, unsigned int &bom_length);
 };
 
 typedef counted_ptr<mm_text_io_c> mm_text_io_cptr;
@@ -280,7 +315,7 @@ public:
   virtual bool eof() {
     return false;
   }
-  virtual string get_file_name() const {
+  virtual std::string get_file_name() const {
     return "";
   }
   virtual void flush();
@@ -288,4 +323,4 @@ public:
 
 typedef counted_ptr<mm_stdio_c> mm_stdio_cptr;
 
-#endif // __MM_IO_H
+#endif // __MTX_COMMON_MM_IO_H
