@@ -18,15 +18,35 @@
 // For PRId64 and PRIu64:
 #define __STDC_FORMAT_MACROS
 
+#if defined(HAVE_SYS_TYPES_H)
+# include <sys/types.h>
+#endif // HAVE_SYS_TYPES_H
+#if defined(HAVE_STDINT_H)
+# include <stdint.h>
+#endif // HAVE_STDINT_H
+#if defined(HAVE_INTTYPES_H)
+# include <inttypes.h>
+#endif // HAVE_INTTYPES_H
+
+#if defined(HAVE_COREC_H)
+#include "corec.h"
+
+#if defined(TARGET_WIN)
+# define SYS_WINDOWS
+#elif defined(TARGET_OSX)
+# define SYS_APPLE
+#elif defined(TARGET_LINUX)
+# define SYS_UNIX
+# if defined(__sun) && defined(__SVR4)
+#  define SYS_SOLARIS
+# else
+#  define SYS_LINUX
+# endif
+#endif
+
+#else // HAVE_COREC_H
 #if defined(_WIN32) || defined(WIN32) || defined(__CYGWIN__) || defined(__MINGW32__)
 # define SYS_WINDOWS
-# if defined __MINGW32__
-#  define COMP_MINGW
-# elif defined __CYGWIN__
-#  define COMP_CYGWIN
-# else
-#  define COMP_MSC
-# endif
 #elif defined(__APPLE__)
 # define SYS_APPLE
 #else
@@ -41,11 +61,24 @@
 # endif
 #endif
 
+#endif // HAVE_COREC_H
+
+#if defined(SYS_WINDOWS)
+# if defined __MINGW32__
+#  define COMP_MINGW
+# elif defined __CYGWIN__
+#  define COMP_CYGWIN
+# else
+#  define COMP_MSC
+#  define NOMINMAX
+# endif
+#endif
+
 #if defined(COMP_MSC)
+
+#if !defined(HAVE_COREC_H)
 # define strncasecmp _strnicmp
 # define strcasecmp _stricmp
-# define nice(a)
-# define vsnprintf _vsnprintf
 typedef __int64 int64_t;
 typedef __int32 int32_t;
 typedef __int16 int16_t;
@@ -54,24 +87,17 @@ typedef unsigned __int64 uint64_t;
 typedef unsigned __int32 uint32_t;
 typedef unsigned __int16 uint16_t;
 typedef unsigned __int8 uint8_t;
+#endif // HAVE_COREC_H
+
+# define nice(a)
 #include <io.h>
 typedef _fsize_t ssize_t;
 
 #define PACKED_STRUCTURE
-#else
+#else // COMP_MSC
 #define PACKED_STRUCTURE   __attribute__((__packed__))
 #endif // COMP_MSC
 
-#if defined(HAVE_SYS_TYPES_H)
-# include <sys/types.h>
-#endif // HAVE_SYS_TYPES_H
-#if defined(HAVE_STDINT_H)
-# include <stdint.h>
-#endif // HAVE_STDINT_H
-#if defined(HAVE_INTTYPES_H)
-# include <inttypes.h>
-#endif // HAVE_INTTYPES_H
-
 #if defined(COMP_MINGW) || defined(COMP_MSC)
 
 // For DLL stuff...
