@@ -6,28 +6,28 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: random.h 2904 2005-05-02 14:55:09Z mosu $
-
    definitions for random number generating functions
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __RANDOM_H
-#define __RANDOM_H
+#ifndef __MTX_COMMON_RANDOM_H
+#define __MTX_COMMON_RANDOM_H
 
-#include "os.h"
+#include "common/common_pch.h"
 
-#include "mm_io.h"
-#include "smart_pointers.h"
+#include "common/mm_io.h"
+#include "common/smart_pointers.h"
 
 class MTX_DLL_API random_c {
 private:
   static bool m_seeded;
 
 #if !defined(SYS_WINDOWS)
-  static auto_ptr<mm_file_io_c> m_dev_urandom;
+  static mm_file_io_cptr m_dev_urandom;
   static bool m_tried_dev_urandom;
+#else
+  static bool m_tried_uuidcreate, m_use_uuidcreate;
 #endif
 
 public:
@@ -74,6 +74,7 @@ public:
   }
 
   static void test();
+  static void cleanup();
 };
 
-#endif // __RANDOM_H
+#endif // __MTX_COMMON_RANDOM_H
