@@ -11,22 +11,17 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "common/os.h"
+#include "common/common_pch.h"
 
 #include <algorithm>
-#include <boost/regex.hpp>
 #if HAVE_NL_LANGINFO
 # include <langinfo.h>
 #elif HAVE_LOCALE_CHARSET
 # include <libcharset.h>
 #endif
-#if defined(HAVE_LIBINTL_H)
-# include <libintl.h>
-#endif
 #include <locale.h>
 #include <stdlib.h>
 
-#include "common/common.h"
 #include "common/locale_string.h"
 #include "common/strings/editing.h"
 #include "common/translation.h"
@@ -87,7 +82,7 @@ translation_c::look_up_translation(const std::string &locale) {
       ++idx;
     }
 
-  } catch (locale_string_format_error_c &error) {
+  } catch (locale_string_format_error_c &) {
   }
 
   return -1;
@@ -273,6 +268,12 @@ init_locales(std::string locale) {
   if (debugging_requested("locale"))
     mxinfo(boost::format("[init_locales chosen locale %1%]\n") % chosen_locale);
 
+  // Hard fallback to "C" locale if no suitable locale was
+  // selected. This can happen if the system has no locales for
+  // "en_US" or "en_US.UTF-8" compiled.
+  if (chosen_locale.empty() && (setlocale(LC_MESSAGES, "C") != NULL))
+    chosen_locale = "C";
+
   if (chosen_locale.empty())
     mxerror(Y("The locale could not be set properly. Check the LANG, LC_ALL and LC_MESSAGES environment variables.\n"));
 
