@@ -11,14 +11,11 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "os.h"
+#include "common/common_pch.h"
 
-#include <boost/format.hpp>
-
-#include "common/common.h"
 #include "common/version.h"
 
-#define VERSIONNAME "Beginnings"
+#define VERSIONNAME "Language"
 
 std::string
 get_version_info(const std::string &program,
