@@ -11,11 +11,10 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "common/os.h"
+#include "common/common_pch.h"
 
 #include <cctype>
 
-#include <ebml/EbmlMaster.h>
 #include <ebml/EbmlUInteger.h>
 #include <ebml/EbmlString.h>
 #include <ebml/EbmlUnicodeString.h>
@@ -24,7 +23,6 @@
 #include <matroska/KaxSegment.h>
 
 #include "common/base64.h"
-#include "common/common.h"
 #include "common/ebml.h"
 #include "common/error.h"
 #include "common/mm_io.h"
@@ -52,7 +50,7 @@ xmlp_parent_name(parser_data_t *pdata,
   int i;
 
   for (i = 0; NULL != pdata->mapping[i].name; i++)
-    if (pdata->mapping[i].id == e->Generic().GlobalId)
+    if (pdata->mapping[i].id == EbmlId(*e))
       return pdata->mapping[i].name;
 
   return Y("(none)");
@@ -270,14 +268,14 @@ add_new_element(parser_data_t *pdata,
     xmlp_error(pdata, boost::format(Y("<%1%> is not a valid child element of <%2%>.")) % name % pdata->mapping[parent_idx].name);
 
   if (0 < pdata->depth) {
-    const EbmlCallbacks *callbacks = find_ebml_callbacks(KaxSegment::ClassInfos, pdata->mapping[parent_idx].id);
+    const EbmlCallbacks *callbacks = find_ebml_callbacks(EBML_INFO(KaxSegment), pdata->mapping[parent_idx].id);
     bool found                     = false;
 
     if (NULL != callbacks) {
-      const EbmlSemanticContext &context = callbacks->Context;
+      const EbmlSemanticContext &context = EBML_INFO_CONTEXT(*callbacks);
       int i;
-      for (i = 0; i < context.Size; i++)
-        if (pdata->mapping[elt_idx].id == context.MyTable[i].GetCallbacks.GlobalId) {
+      for (i = 0; i < EBML_CTX_SIZE(context); i++)
+        if (pdata->mapping[elt_idx].id == EBML_SEM_ID(context.MyTable[i])) {
           found = true;
           break;
         }
@@ -286,19 +284,19 @@ add_new_element(parser_data_t *pdata,
     if (!found)
       xmlp_error(pdata, boost::format(Y("<%1%> is not a valid child element of <%2%>.")) % name % pdata->mapping[parent_idx].name);
 
-    const EbmlSemantic *semantic = find_ebml_semantic(KaxSegment::ClassInfos, pdata->mapping[elt_idx].id);
-    if ((NULL != semantic) && semantic->Unique) {
+    const EbmlSemantic *semantic = find_ebml_semantic(EBML_INFO(KaxSegment), pdata->mapping[elt_idx].id);
+    if ((NULL != semantic) && EBML_SEM_UNIQUE(*semantic)) {
       EbmlMaster *m = dynamic_cast<EbmlMaster *>(xmlp_pelt);
       assert(NULL != m);
 
       int i;
       for (i = 0; i < m->ListSize(); i++)
-        if ((*m)[i]->Generic().GlobalId == pdata->mapping[elt_idx].id)
+        if (EbmlId(*(*m)[i]) == pdata->mapping[elt_idx].id)
           xmlp_error(pdata, boost::format(Y("Only one instance of <%1%> is allowed beneath <%2%>.")) % name % pdata->mapping[parent_idx].name);
     }
   }
 
-  EbmlElement *e = create_ebml_element(KaxSegment::ClassInfos, pdata->mapping[elt_idx].id);
+  EbmlElement *e = create_ebml_element(EBML_INFO(KaxSegment), pdata->mapping[elt_idx].id);
   assert(NULL != e);
 
   if (0 == pdata->depth) {
