@@ -10,12 +10,10 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "common/os.h"
+#include "common/common_pch.h"
 
 #include <cassert>
 #include <algorithm>
-#include <string>
-#include <vector>
 
 #include <ebml/EbmlHead.h>
 #include <ebml/EbmlSubHead.h>
@@ -33,7 +31,6 @@
 #include <matroska/KaxTracks.h>
 #include <matroska/KaxTrackEntryData.h>
 
-#include "common/common.h"
 #include "common/ebml.h"
 #include "common/matroska.h"
 #include "common/mm_io.h"
@@ -178,7 +175,7 @@ extract_timecodes(const std::string &file_name,
     EbmlStream *es    = new EbmlStream(*in);
 
     // Find the EbmlHead element. Must be the first one.
-    EbmlElement *l0 = es->FindNextID(EbmlHead::ClassInfos, 0xFFFFFFFFL);
+    EbmlElement *l0 = es->FindNextID(EBML_INFO(EbmlHead), 0xFFFFFFFFL);
     if (l0 == NULL) {
       show_error(Y("Error: No EBML head found."));
       delete es;
@@ -187,22 +184,22 @@ extract_timecodes(const std::string &file_name,
     }
 
     // Don't verify its data for now.
-    l0->SkipData(*es, l0->Generic().Context);
+    l0->SkipData(*es, EBML_CONTEXT(l0));
     delete l0;
 
     while (1) {
       // Next element must be a segment
-      l0 = es->FindNextID(KaxSegment::ClassInfos, 0xFFFFFFFFFFFFFFFFLL);
+      l0 = es->FindNextID(EBML_INFO(KaxSegment), 0xFFFFFFFFFFFFFFFFLL);
       if (NULL == l0) {
         show_error(Y("No segment/level 0 element found."));
         return;
       }
-      if (EbmlId(*l0) == KaxSegment::ClassInfos.GlobalId) {
+      if (EbmlId(*l0) == EBML_ID(KaxSegment)) {
         show_element(l0, 0, Y("Segment"));
         break;
       }
 
-      l0->SkipData(*es, l0->Generic().Context);
+      l0->SkipData(*es, EBML_CONTEXT(l0));
       delete l0;
     }
 
@@ -211,25 +208,25 @@ extract_timecodes(const std::string &file_name,
     uint64_t tc_scale = TIMECODE_SCALE;
 
     // We've got our segment, so let's find the tracks
-    EbmlElement *l1   = es->FindNextElement(l0->Generic().Context, upper_lvl_el, 0xFFFFFFFFL, true, 1);
+    EbmlElement *l1   = es->FindNextElement(EBML_CONTEXT(l0), upper_lvl_el, 0xFFFFFFFFL, true, 1);
     EbmlElement *l2   = NULL;
     EbmlElement *l3   = NULL;
 
     while ((NULL != l1) && (0 >= upper_lvl_el)) {
-      if (EbmlId(*l1) == KaxInfo::ClassInfos.GlobalId) {
+      if (EbmlId(*l1) == EBML_ID(KaxInfo)) {
         // General info about this Matroska file
         show_element(l1, 1, Y("Segment information"));
 
         upper_lvl_el = 0;
-        l2           = es->FindNextElement(l1->Generic().Context, upper_lvl_el, 0xFFFFFFFFL, true, 1);
+        l2           = es->FindNextElement(EBML_CONTEXT(l1), upper_lvl_el, 0xFFFFFFFFL, true, 1);
         while ((NULL != l2) && (0 >= upper_lvl_el)) {
-          if (EbmlId(*l2) == KaxTimecodeScale::ClassInfos.GlobalId) {
+          if (EbmlId(*l2) == EBML_ID(KaxTimecodeScale)) {
             KaxTimecodeScale &ktc_scale = *static_cast<KaxTimecodeScale *>(l2);
             ktc_scale.ReadData(es->I_O());
             tc_scale = uint64(ktc_scale);
             show_element(l2, 2, boost::format(Y("Timecode scale: %1%")) % tc_scale);
           } else
-            l2->SkipData(*es, l2->Generic().Context);
+            l2->SkipData(*es, EBML_CONTEXT(l2));
 
           if (!in_parent(l1)) {
             delete l2;
@@ -243,22 +240,22 @@ extract_timecodes(const std::string &file_name,
 
           }
 
-          l2->SkipData(*es, l2->Generic().Context);
+          l2->SkipData(*es, EBML_CONTEXT(l2));
           delete l2;
-          l2 = es->FindNextElement(l1->Generic().Context, upper_lvl_el, 0xFFFFFFFFL, true);
+          l2 = es->FindNextElement(EBML_CONTEXT(l1), upper_lvl_el, 0xFFFFFFFFL, true);
         }
 
-      } else if ((EbmlId(*l1) == KaxTracks::ClassInfos.GlobalId) && !tracks_found) {
+      } else if ((EbmlId(*l1) == EBML_ID(KaxTracks)) && !tracks_found) {
 
         // Yep, we've found our KaxTracks element. Now find all tracks
         // contained in this segment.
         show_element(l1, 1, Y("Segment tracks"));
 
         tracks_found = true;
-        l1->Read(*es, KaxTracks::ClassInfos.Context, upper_lvl_el, l2, true);
+        l1->Read(*es, EBML_INFO_CONTEXT(EBML_INFO(KaxTracks)), upper_lvl_el, l2, true);
         create_timecode_files(*dynamic_cast<KaxTracks *>(l1), tspecs, version);
 
-      } else if (EbmlId(*l1) == KaxCluster::ClassInfos.GlobalId) {
+      } else if (EbmlId(*l1) == EBML_ID(KaxCluster)) {
         show_element(l1, 1, Y("Cluster"));
         KaxCluster *cluster = (KaxCluster *)l1;
         uint64_t cluster_tc = 0;
@@ -267,30 +264,30 @@ extract_timecodes(const std::string &file_name,
           mxinfo(boost::format(Y("Progress: %1%%%%2%")) % (int)(in->getFilePointer() * 100 / file_size) % "\r");
 
         upper_lvl_el = 0;
-        l2           = es->FindNextElement(l1->Generic().Context, upper_lvl_el, 0xFFFFFFFFL, true, 1);
+        l2           = es->FindNextElement(EBML_CONTEXT(l1), upper_lvl_el, 0xFFFFFFFFL, true, 1);
         while ((NULL != l2) && (0 >= upper_lvl_el)) {
 
-          if (EbmlId(*l2) == KaxClusterTimecode::ClassInfos.GlobalId) {
+          if (EbmlId(*l2) == EBML_ID(KaxClusterTimecode)) {
             KaxClusterTimecode &ctc = *static_cast<KaxClusterTimecode *>(l2);
             ctc.ReadData(es->I_O());
             cluster_tc = uint64(ctc);
             show_element(l2, 2, boost::format(Y("Cluster timecode: %|1$.3f|s")) % ((float)cluster_tc * (float)tc_scale / 1000000000.0));
             cluster->InitTimecode(cluster_tc, tc_scale);
 
-          } else if (EbmlId(*l2) == KaxBlockGroup::ClassInfos.GlobalId) {
+          } else if (EbmlId(*l2) == EBML_ID(KaxBlockGroup)) {
             show_element(l2, 2, Y("Block group"));
 
-            l2->Read(*es, KaxBlockGroup::ClassInfos.Context, upper_lvl_el, l3, true);
+            l2->Read(*es, EBML_INFO_CONTEXT(EBML_INFO(KaxBlockGroup)), upper_lvl_el, l3, true);
             handle_blockgroup(*static_cast<KaxBlockGroup *>(l2), *cluster, tc_scale);
 
-          } else if (EbmlId(*l2) == KaxSimpleBlock::ClassInfos.GlobalId) {
+          } else if (EbmlId(*l2) == EBML_ID(KaxSimpleBlock)) {
             show_element(l2, 2, Y("Simple block"));
 
-            l2->Read(*es, KaxSimpleBlock::ClassInfos.Context, upper_lvl_el, l3, true);
+            l2->Read(*es, EBML_INFO_CONTEXT(EBML_INFO(KaxSimpleBlock)), upper_lvl_el, l3, true);
             handle_simpleblock(*static_cast<KaxSimpleBlock *>(l2), *cluster);
 
           } else
-            l2->SkipData(*es, l2->Generic().Context);
+            l2->SkipData(*es, EBML_CONTEXT(l2));
 
           if (!in_parent(l1)) {
             delete l2;
@@ -312,14 +309,14 @@ extract_timecodes(const std::string &file_name,
 
           }
 
-          l2->SkipData(*es, l2->Generic().Context);
+          l2->SkipData(*es, EBML_CONTEXT(l2));
           delete l2;
-          l2 = es->FindNextElement(l1->Generic().Context, upper_lvl_el, 0xFFFFFFFFL, true);
+          l2 = es->FindNextElement(EBML_CONTEXT(l1), upper_lvl_el, 0xFFFFFFFFL, true);
 
         } // while (l2 != NULL)
 
       } else
-        l1->SkipData(*es, l1->Generic().Context);
+        l1->SkipData(*es, EBML_CONTEXT(l1));
 
       if (!in_parent(l0)) {
         delete l1;
@@ -341,9 +338,9 @@ extract_timecodes(const std::string &file_name,
 
       }
 
-      l1->SkipData(*es, l1->Generic().Context);
+      l1->SkipData(*es, EBML_CONTEXT(l1));
       delete l1;
-      l1 = es->FindNextElement(l0->Generic().Context, upper_lvl_el, 0xFFFFFFFFL, true);
+      l1 = es->FindNextElement(EBML_CONTEXT(l0), upper_lvl_el, 0xFFFFFFFFL, true);
 
     } // while (l1 != NULL)
 
