@@ -10,11 +10,9 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "common/os.h"
+#include "common/common_pch.h"
 
 #include <cassert>
-#include <string>
-#include <vector>
 
 #include <ebml/EbmlHead.h>
 #include <ebml/EbmlSubHead.h>
@@ -34,8 +32,8 @@
 #include <matroska/KaxTrackAudio.h>
 #include <matroska/KaxTrackVideo.h>
 
-#include "common/common.h"
 #include "common/ebml.h"
+#include "common/kax_file.h"
 #include "common/matroska.h"
 #include "common/mm_io.h"
 #include "extract/mkvextract.h"
@@ -309,9 +307,11 @@ bool
 extract_tracks(const std::string &file_name,
                std::vector<track_spec_t> &tspecs) {
   // open input file
-  mm_io_c *in;
+  mm_io_cptr in;
+  kax_file_cptr file;
   try {
-    in = new mm_file_io_c(file_name, MODE_READ);
+    in   = mm_io_cptr(new mm_file_io_c(file_name, MODE_READ));
+    file = kax_file_cptr(new kax_file_c(in));
   } catch (...) {
     show_error(boost::format(Y("The file '%1%' could not be opened for reading (%2%).\n")) % file_name % strerror(errno));
     return false;
@@ -323,7 +323,7 @@ extract_tracks(const std::string &file_name,
     EbmlStream *es = new EbmlStream(*in);
 
     // Find the EbmlHead element. Must be the first one.
-    EbmlElement *l0 = es->FindNextID(EbmlHead::ClassInfos, 0xFFFFFFFFL);
+    EbmlElement *l0 = es->FindNextID(EBML_INFO(EbmlHead), 0xFFFFFFFFL);
     if (NULL == l0) {
       show_error(Y("Error: No EBML head found."));
       delete es;
@@ -332,154 +332,92 @@ extract_tracks(const std::string &file_name,
     }
 
     // Don't verify its data for now.
-    l0->SkipData(*es, l0->Generic().Context);
+    l0->SkipData(*es, EBML_CONTEXT(l0));
     delete l0;
 
     while (1) {
       // Next element must be a segment
-      l0 = es->FindNextID(KaxSegment::ClassInfos, 0xFFFFFFFFFFFFFFFFLL);
+      l0 = es->FindNextID(EBML_INFO(KaxSegment), 0xFFFFFFFFFFFFFFFFLL);
 
       if (NULL == l0) {
         show_error(Y("No segment/level 0 element found."));
         return false;
       }
 
-      if (EbmlId(*l0) == KaxSegment::ClassInfos.GlobalId) {
+      if (EbmlId(*l0) == EBML_ID(KaxSegment)) {
         show_element(l0, 0, Y("Segment"));
         break;
       }
 
-      l0->SkipData(*es, l0->Generic().Context);
+      l0->SkipData(*es, EBML_CONTEXT(l0));
       delete l0;
     }
 
     bool tracks_found = false;
-    int upper_lvl_el  = 0;
-    // We've got our segment, so let's find the tracks
-    EbmlElement *l1     = es->FindNextElement(l0->Generic().Context, upper_lvl_el, 0xFFFFFFFFFFFFFFFFLL, true, 1);
-    EbmlElement *l2     = NULL;
-    EbmlElement *l3     = NULL;
+    EbmlElement *l1   = NULL;
+    uint64_t tc_scale = TIMECODE_SCALE;
 
-    uint64_t tc_scale   = TIMECODE_SCALE;
-    uint64_t cluster_tc = 0;
-
-    KaxCluster *cluster = NULL;
     KaxChapters all_chapters;
     KaxTags all_tags;
 
-    while ((NULL != l1) && (0 >= upper_lvl_el)) {
-      if (EbmlId(*l1) == KaxInfo::ClassInfos.GlobalId) {
+    while (NULL != (l1 = file->read_next_level1_element())) {
+      int64_t element_end_pos = l1->GetElementPosition() + l1->ElementSize();
+
+      if (EbmlId(*l1) == EBML_ID(KaxInfo)) {
         // General info about this Matroska file
         show_element(l1, 1, Y("Segment information"));
 
-        upper_lvl_el = 0;
-        l2           = es->FindNextElement(l1->Generic().Context, upper_lvl_el, 0xFFFFFFFFL, true, 1);
-
-        while ((NULL != l2) && (0 >= upper_lvl_el)) {
-
-          if (EbmlId(*l2) == KaxTimecodeScale::ClassInfos.GlobalId) {
-            KaxTimecodeScale &ktc_scale = *static_cast<KaxTimecodeScale *>(l2);
-            ktc_scale.ReadData(es->I_O());
-            tc_scale = uint64(ktc_scale);
-            show_element(l2, 2, boost::format(Y("Timecode scale: %1%")) % tc_scale);
-          } else
-            l2->SkipData(*es, l2->Generic().Context);
-
-          if (!in_parent(l1)) {
-            delete l2;
-            break;
-          }
-
-          if (0 > upper_lvl_el) {
-            upper_lvl_el++;
-            if (0 > upper_lvl_el)
-              break;
-
-          }
-
-          l2->SkipData(*es, l2->Generic().Context);
-          delete l2;
-          l2 = es->FindNextElement(l1->Generic().Context, upper_lvl_el, 0xFFFFFFFFL, true);
+        KaxTimecodeScale *ktc_scale = FINDFIRST(l1, KaxTimecodeScale);
+        if (NULL != ktc_scale) {
+          tc_scale = uint64(*ktc_scale);
+          show_element(ktc_scale, 2, boost::format(Y("Timecode scale: %1%")) % tc_scale);
         }
 
-      } else if ((EbmlId(*l1) == KaxTracks::ClassInfos.GlobalId) && !tracks_found) {
+      } else if ((EbmlId(*l1) == EBML_ID(KaxTracks)) && !tracks_found) {
 
         // Yep, we've found our KaxTracks element. Now find all tracks
         // contained in this segment.
         show_element(l1, 1, Y("Segment tracks"));
 
         tracks_found = true;
-        l1->Read(*es, KaxTracks::ClassInfos.Context, upper_lvl_el, l2, true);
         find_track_uids(*dynamic_cast<KaxTracks *>(l1), tspecs);
         create_extractors(*dynamic_cast<KaxTracks *>(l1), tspecs);
 
-      } else if (EbmlId(*l1) == KaxCluster::ClassInfos.GlobalId) {
+      } else if (EbmlId(*l1) == EBML_ID(KaxCluster)) {
         show_element(l1, 1, Y("Cluster"));
-        cluster = (KaxCluster *)l1;
+        KaxCluster *cluster = static_cast<KaxCluster *>(l1);
 
         if (0 == verbose)
           mxinfo(boost::format(Y("Progress: %1%%%%2%")) % (int)(in->getFilePointer() * 100 / file_size) % "\r");
 
-        upper_lvl_el = 0;
-        l2           = es->FindNextElement(l1->Generic().Context, upper_lvl_el, 0xFFFFFFFFL, true, 1);
-        while ((NULL != l2) && (0 >= upper_lvl_el)) {
+        KaxClusterTimecode *ctc = FINDFIRST(l1, KaxClusterTimecode);
+        if (NULL != ctc) {
+          uint64_t cluster_tc = uint64(*ctc);
+          show_element(ctc, 2, boost::format(Y("Cluster timecode: %|1$.3f|s")) % ((float)cluster_tc * (float)tc_scale / 1000000000.0));
+          cluster->InitTimecode(cluster_tc, tc_scale);
+        }
 
-          if (EbmlId(*l2) == KaxClusterTimecode::ClassInfos.GlobalId) {
-            KaxClusterTimecode &ctc = *static_cast<KaxClusterTimecode *>(l2);
-            ctc.ReadData(es->I_O());
-            cluster_tc = uint64(ctc);
-            show_element(l2, 2, boost::format(Y("Cluster timecode: %|1$.3f|s")) % ((float)cluster_tc * (float)tc_scale / 1000000000.0));
-            cluster->InitTimecode(cluster_tc, tc_scale);
+        int i;
+        for (i = 0; cluster->ListSize() > i; ++i) {
+          EbmlElement *el = (*cluster)[i];
+          if (EbmlId(*el) == EBML_ID(KaxBlockGroup)) {
+            show_element(el, 2, Y("Block group"));
+            handle_blockgroup(*static_cast<KaxBlockGroup *>(el), *cluster, tc_scale);
 
-          } else if (EbmlId(*l2) == KaxBlockGroup::ClassInfos.GlobalId) {
-            show_element(l2, 2, Y("Block group"));
-
-            l2->Read(*es, KaxBlockGroup::ClassInfos.Context, upper_lvl_el, l3, true);
-            handle_blockgroup(*static_cast<KaxBlockGroup *>(l2), *cluster, tc_scale);
-
-          } else if (EbmlId(*l2) == KaxSimpleBlock::ClassInfos.GlobalId) {
-            show_element(l2, 2, Y("SimpleBlock"));
-
-            l2->Read(*es, KaxSimpleBlock::ClassInfos.Context, upper_lvl_el, l3, true);
-            handle_simpleblock(*static_cast<KaxSimpleBlock *>(l2), *cluster);
-
-          } else
-            l2->SkipData(*es, l2->Generic().Context);
-
-          if (!in_parent(l1)) {
-            delete l2;
-            break;
+          } else if (EbmlId(*el) == EBML_ID(KaxSimpleBlock)) {
+            show_element(el, 2, Y("SimpleBlock"));
+            handle_simpleblock(*static_cast<KaxSimpleBlock *>(el), *cluster);
           }
+        }
 
-          if (0 < upper_lvl_el) {
-            upper_lvl_el--;
-            if (0 < upper_lvl_el)
-              break;
-            delete l2;
-            l2 = l3;
-            continue;
-
-          } else if (0 > upper_lvl_el) {
-            upper_lvl_el++;
-            if (0 > upper_lvl_el)
-              break;
-
-          }
-
-          l2->SkipData(*es, l2->Generic().Context);
-          delete l2;
-          l2 = es->FindNextElement(l1->Generic().Context, upper_lvl_el, 0xFFFFFFFFL, true);
-
-        } // while (l2 != NULL)
-
-      } else if (EbmlId(*l1) == KaxChapters::ClassInfos.GlobalId) {
+      } else if (EbmlId(*l1) == EBML_ID(KaxChapters)) {
         KaxChapters &chapters = *static_cast<KaxChapters *>(l1);
-        chapters.Read(*es, KaxChapters::ClassInfos.Context, upper_lvl_el, l2, true);
+
         while (chapters.ListSize() > 0) {
-          if (EbmlId(*chapters[0]) == KaxEditionEntry::ClassInfos.GlobalId) {
+          if (EbmlId(*chapters[0]) == EBML_ID(KaxEditionEntry)) {
             KaxEditionEntry &entry = *static_cast<KaxEditionEntry *>(chapters[0]);
             while (entry.ListSize() > 0) {
-              if (EbmlId(*entry[0]) == KaxChapterAtom::ClassInfos.GlobalId)
+              if (EbmlId(*entry[0]) == EBML_ID(KaxChapterAtom))
                 all_chapters.PushElement(*entry[0]);
               entry.Remove(0);
             }
@@ -487,47 +425,23 @@ extract_tracks(const std::string &file_name,
           chapters.Remove(0);
         }
 
-      } else if (EbmlId(*l1) == KaxTags::ClassInfos.GlobalId) {
+      } else if (EbmlId(*l1) == EBML_ID(KaxTags)) {
         KaxTags &tags = *static_cast<KaxTags *>(l1);
-        tags.Read(*es, KaxTags::ClassInfos.Context, upper_lvl_el, l2, true);
 
         while (tags.ListSize() > 0) {
           all_tags.PushElement(*tags[0]);
           tags.Remove(0);
         }
 
-      } else
-        l1->SkipData(*es, l1->Generic().Context);
-
-      if (!in_parent(l0)) {
-        delete l1;
-        break;
       }
 
-      if (0 < upper_lvl_el) {
-        upper_lvl_el--;
-        if (0 < upper_lvl_el)
-          break;
-        delete l1;
-        l1 = l2;
-        continue;
-
-      } else if (0 > upper_lvl_el) {
-        upper_lvl_el++;
-        if (0 > upper_lvl_el)
-          break;
-
-      }
-
-      l1->SkipData(*es, l1->Generic().Context);
+      in->setFilePointer(element_end_pos, seek_beginning);
       delete l1;
-      l1 = es->FindNextElement(l0->Generic().Context, upper_lvl_el, 0xFFFFFFFFL, true);
 
     } // while (l1 != NULL)
 
     delete l0;
     delete es;
-    delete in;
 
     write_all_cuesheets(all_chapters, all_tags, tspecs);
 
@@ -539,7 +453,6 @@ extract_tracks(const std::string &file_name,
     return true;
   } catch (...) {
     show_error(Y("Caught exception"));
-    delete in;
 
     return false;
   }
