@@ -10,18 +10,19 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "common.h"
-#include "commonebml.h"
-#include "random.h"
-#include "kate_common.h"
-
-#include "xtr_ogg.h"
+#include "common/common_pch.h"
 
 #include <vorbis/codec.h>
 
+#include "common/ebml.h"
+#include "common/endian.h"
+#include "common/random.h"
+#include "common/kate.h"
+#include "extract/xtr_ogg.h"
+
 // ------------------------------------------------------------------------
 
-xtr_flac_c::xtr_flac_c(const string &_codec_id,
+xtr_flac_c::xtr_flac_c(const std::string &_codec_id,
                        int64_t _tid,
                        track_spec_t &tspec)
   : xtr_base_c(_codec_id, _tid, tspec)
@@ -38,12 +39,12 @@ xtr_flac_c::create_file(xtr_base_c *_master,
   xtr_base_c::create_file(_master, track);
 
   memory_cptr mpriv = decode_codec_private(priv);
-  m_out->write(mpriv->get(), mpriv->get_size());
+  m_out->write(mpriv);
 }
 
 // ------------------------------------------------------------------------
 
-xtr_oggbase_c::xtr_oggbase_c(const string &codec_id,
+xtr_oggbase_c::xtr_oggbase_c(const std::string &codec_id,
                              int64_t tid,
                              track_spec_t &tspec)
   : xtr_base_c(codec_id, tid, tspec)
@@ -73,7 +74,7 @@ xtr_oggbase_c::create_standard_file(xtr_base_c *master,
   init_content_decoder(track);
   memory_cptr mpriv = decode_codec_private(priv);
 
-  vector<memory_cptr> header_packets;
+  std::vector<memory_cptr> header_packets;
   try {
     header_packets = unlace_memory_xiph(mpriv);
 
@@ -94,7 +95,7 @@ xtr_oggbase_c::create_standard_file(xtr_base_c *master,
     op.b_o_s      = (0 == m_packetno ? 1 : 0);
     op.e_o_s      = 0;
     op.packetno   = m_packetno;
-    op.packet     = header_packets[m_packetno]->get();
+    op.packet     = header_packets[m_packetno]->get_buffer();
     op.bytes      = header_packets[m_packetno]->get_size();
     op.granulepos = 0;
     ogg_stream_packetin(&m_os, &op);
@@ -108,7 +109,7 @@ xtr_oggbase_c::create_standard_file(xtr_base_c *master,
 }
 
 void
-xtr_oggbase_c::header_packets_unlaced(vector<memory_cptr> &header_packets) {
+xtr_oggbase_c::header_packets_unlaced(std::vector<memory_cptr> &header_packets) {
 }
 
 void
@@ -188,7 +189,7 @@ xtr_oggbase_c::write_queued_frame(bool eos) {
   op.b_o_s      = 0;
   op.e_o_s      = eos ? 1 : 0;
   op.packetno   = m_packetno;
-  op.packet     = m_queued_frame->get();
+  op.packet     = m_queued_frame->get_buffer();
   op.bytes      = m_queued_frame->get_size();
   op.granulepos = m_queued_granulepos;
 
@@ -203,7 +204,7 @@ xtr_oggbase_c::write_queued_frame(bool eos) {
 
 // ------------------------------------------------------------------------
 
-xtr_oggflac_c::xtr_oggflac_c(const string &codec_id,
+xtr_oggflac_c::xtr_oggflac_c(const std::string &codec_id,
                              int64_t tid,
                              track_spec_t &tspec)
   : xtr_oggbase_c(codec_id, tid, tspec)
@@ -238,7 +239,7 @@ xtr_oggflac_c::create_file(xtr_base_c *master,
   ogg_stream_packetin(&m_os, &op);
   flush_pages();
 
-  const binary *ptr = mpriv->get();
+  const binary *ptr = mpriv->get_buffer();
   if ((mpriv->get_size() >= 4) && !memcmp(ptr, "fLaC", 4)) {
     ptr      += 4;
     op.bytes  = mpriv->get_size() - 4;
@@ -258,11 +259,20 @@ xtr_oggflac_c::create_file(xtr_base_c *master,
 
 // ------------------------------------------------------------------------
 
-xtr_oggvorbis_c::xtr_oggvorbis_c(const string &codec_id,
+xtr_oggvorbis_c::xtr_oggvorbis_c(const std::string &codec_id,
                                  int64_t tid,
                                  track_spec_t &tspec)
   : xtr_oggbase_c(codec_id, tid, tspec)
+  , m_previous_block_size(-1)
+  , m_samples(0)
 {
+  vorbis_info_init(&m_vorbis_info);
+  vorbis_comment_init(&m_vorbis_comment);
+}
+
+xtr_oggvorbis_c::~xtr_oggvorbis_c() {
+  vorbis_info_clear(&m_vorbis_info);
+  vorbis_comment_clear(&m_vorbis_comment);
 }
 
 void
@@ -271,24 +281,68 @@ xtr_oggvorbis_c::create_file(xtr_base_c *master,
   create_standard_file(master, track);
 }
 
+void
+xtr_oggvorbis_c::header_packets_unlaced(std::vector<memory_cptr> &header_packets) {
+  int packet_num = 0;
+  foreach(memory_cptr &packet, header_packets) {
+    ogg_packet op;
+    op.packet   = packet->get_buffer();
+    op.bytes    = packet->get_size();
+    op.b_o_s    = 0 == packet_num;
+    op.packetno = packet_num;
+    ++packet_num;
+
+    vorbis_synthesis_headerin(&m_vorbis_info, &m_vorbis_comment, &op);
+  }
+}
+
+
+void
+xtr_oggvorbis_c::handle_frame(memory_cptr &frame,
+                              KaxBlockAdditions *additions,
+                              int64_t timecode,
+                              int64_t duration,
+                              int64_t bref,
+                              int64_t fref,
+                              bool keyframe,
+                              bool discardable,
+                              bool references_valid) {
+  m_content_decoder.reverse(frame, CONTENT_ENCODING_SCOPE_BLOCK);
+
+  ogg_packet op;
+  op.packet               = frame->get_buffer();
+  op.bytes                = frame->get_size();
+  int64_t this_block_size = vorbis_packet_blocksize(&m_vorbis_info, &op);
+
+  if (-1 != m_previous_block_size) {
+    m_queued_granulepos   = m_samples;
+    m_samples            += (this_block_size + m_previous_block_size) / 4;
+  }
+
+  m_previous_end        = m_samples * 1000000000 / m_sfreq;
+  m_previous_block_size = this_block_size;
+
+  queue_frame(frame, 0);
+}
+
 // ------------------------------------------------------------------------
 
-xtr_oggkate_c::xtr_oggkate_c(const string &codec_id,
-                                 int64_t tid,
-                                 track_spec_t &tspec)
-  : xtr_oggbase_c(codec_id, tid, tspec) 
+xtr_oggkate_c::xtr_oggkate_c(const std::string &codec_id,
+                             int64_t tid,
+                             track_spec_t &tspec)
+  : xtr_oggbase_c(codec_id, tid, tspec)
 {
 }
 
 void
 xtr_oggkate_c::create_file(xtr_base_c *master,
-                             KaxTrackEntry &track) {
+                           KaxTrackEntry &track) {
   create_standard_file(master, track);
 }
 
 void
-xtr_oggkate_c::header_packets_unlaced(vector<memory_cptr> &header_packets) {
-  kate_parse_identification_header(header_packets[0]->get(), header_packets[0]->get_size(), m_kate_id_header);
+xtr_oggkate_c::header_packets_unlaced(std::vector<memory_cptr> &header_packets) {
+  kate_parse_identification_header(header_packets[0]->get_buffer(), header_packets[0]->get_size(), m_kate_id_header);
   if (m_kate_id_header.nheaders != header_packets.size())
     throw false;
 }
@@ -307,9 +361,9 @@ xtr_oggkate_c::handle_frame(memory_cptr &frame,
 
   ogg_packet op;
   op.b_o_s    = 0;
-  op.e_o_s    = (frame->get_size() == 1) && (frame->get()[0] == 0x7f);
+  op.e_o_s    = (frame->get_size() == 1) && (frame->get_buffer()[0] == 0x7f);
   op.packetno = m_packetno;
-  op.packet   = frame->get();
+  op.packet   = frame->get_buffer();
   op.bytes    = frame->get_size();
 
   /* we encode the backlink in the granulepos */
@@ -334,7 +388,7 @@ xtr_oggkate_c::handle_frame(memory_cptr &frame,
 
 // ------------------------------------------------------------------------
 
-xtr_oggtheora_c::xtr_oggtheora_c(const string &codec_id,
+xtr_oggtheora_c::xtr_oggtheora_c(const std::string &codec_id,
                                  int64_t tid,
                                  track_spec_t &tspec)
   : xtr_oggbase_c(codec_id, tid, tspec)
@@ -350,8 +404,8 @@ xtr_oggtheora_c::create_file(xtr_base_c *master,
 }
 
 void
-xtr_oggtheora_c::header_packets_unlaced(vector<memory_cptr> &header_packets) {
-  theora_parse_identification_header(header_packets[0]->get(), header_packets[0]->get_size(), m_theora_header);
+xtr_oggtheora_c::header_packets_unlaced(std::vector<memory_cptr> &header_packets) {
+  theora_parse_identification_header(header_packets[0]->get_buffer(), header_packets[0]->get_size(), m_theora_header);
 }
 
 void
@@ -366,7 +420,7 @@ xtr_oggtheora_c::handle_frame(memory_cptr &frame,
                               bool references_valid) {
   m_content_decoder.reverse(frame, CONTENT_ENCODING_SCOPE_BLOCK);
 
-  if (frame->get_size() && (0x00 == (frame->get()[0] & 0x40))) {
+  if (frame->get_size() && (0x00 == (frame->get_buffer()[0] & 0x40))) {
     keyframe               = true;
     m_keyframe_number     += m_non_keyframe_number + 1;
     m_non_keyframe_number  = 0;
