@@ -10,24 +10,24 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "os.h"
+#include "common/common_pch.h"
 
 #include <algorithm>
 
-#include "common.h"
-#include "commonebml.h"
-#include "matroska.h"
-#include "smart_pointers.h"
+#include "common/ebml.h"
+#include "common/matroska.h"
+#include "common/strings/editing.h"
+#include "common/strings/formatting.h"
+#include "common/strings/parsing.h"
+#include "extract/xtr_textsubs.h"
 
-#include "xtr_textsubs.h"
-
-xtr_srt_c::xtr_srt_c(const string &codec_id,
+xtr_srt_c::xtr_srt_c(const std::string &codec_id,
                      int64_t tid,
                      track_spec_t &tspec)
   : xtr_base_c(codec_id, tid, tspec)
   , m_num_entries(0)
   , m_sub_charset(tspec.sub_charset)
-  , m_conv(utf8_init(tspec.sub_charset))
+  , m_conv(charset_converter_c::init(tspec.sub_charset))
 {
 }
 
@@ -60,17 +60,17 @@ xtr_srt_c::handle_frame(memory_cptr &frame,
 
   ++m_num_entries;
   char *text = new char[frame->get_size() + 1];
-  memcpy(text, frame->get(), frame->get_size());
+  memcpy(text, frame->get_buffer(), frame->get_size());
   text[frame->get_size()] = 0;
 
-  string buffer =
+  std::string buffer =
     (boost::format("%1%\n"
                    "%|2$02d|:%|3$02d|:%|4$02d|,%|5$03d| --> %|6$02d|:%|7$02d|:%|8$02d|,%|9$03d|\n"
                    "%10%\n\n")
      % m_num_entries
      % (start / 1000 / 60 / 60) % ((start / 1000 / 60) % 60) % ((start / 1000) % 60) % (start % 1000)
      % (end   / 1000 / 60 / 60) % ((end   / 1000 / 60) % 60) % ((end   / 1000) % 60) % (end   % 1000)
-     % from_utf8(m_conv, text)
+     % m_conv->native(text)
      ).str();
 
   m_out->puts(buffer);
@@ -85,12 +85,12 @@ const char *xtr_ssa_c::ms_kax_ssa_fields[10] = {
   "effect",    "text",    NULL
 };
 
-xtr_ssa_c::xtr_ssa_c(const string &codec_id,
+xtr_ssa_c::xtr_ssa_c(const std::string &codec_id,
                      int64_t tid,
                      track_spec_t &tspec)
   : xtr_base_c(codec_id, tid, tspec)
   , m_sub_charset(tspec.sub_charset)
-  , m_conv(utf8_init(tspec.sub_charset))
+  , m_conv(charset_converter_c::init(tspec.sub_charset))
   , m_warning_printed(false)
 {
 }
@@ -107,7 +107,7 @@ xtr_ssa_c::create_file(xtr_base_c *master,
 
   memory_cptr mpriv = decode_codec_private(priv);
 
-  const unsigned char *pd = mpriv->get();
+  const unsigned char *pd = mpriv->get_buffer();
   int priv_size           = mpriv->get_size();
   int bom_len             = 0;
 
@@ -123,13 +123,13 @@ xtr_ssa_c::create_file(xtr_base_c *master,
   else if ((2 < priv_size) && (0xfe == pd[0]) && (0xff == pd[1]))
     bom_len = 2;
 
-  pd           += bom_len;
-  priv_size    -= bom_len;
+  pd                += bom_len;
+  priv_size         -= bom_len;
 
-  char *s       = new char[priv_size + 1];
+  char *s            = new char[priv_size + 1];
   memcpy(s, pd, priv_size);
-  s[priv_size]  = 0;
-  string sconv  = s;
+  s[priv_size]       = 0;
+  std::string sconv  = s;
   delete []s;
 
   const char *p1;
@@ -157,7 +157,7 @@ xtr_ssa_c::create_file(xtr_base_c *master,
   for (pos1 = 0; m_ssa_format.size() > pos1; ++pos1)
     m_ssa_format[pos1] = downcase(m_ssa_format[pos1]);
 
-  sconv = from_utf8(m_conv, sconv);
+  sconv = m_conv->native(sconv);
   m_out->puts(sconv);
 }
 
@@ -186,14 +186,14 @@ xtr_ssa_c::handle_frame(memory_cptr &frame,
 
   char *s       = (char *)safemalloc(frame->get_size() + 1);
   memory_c af_s((unsigned char *)s, 0, true);
-  memcpy(s, frame->get(), frame->get_size());
+  memcpy(s, frame->get_buffer(), frame->get_size());
   s[frame->get_size()] = 0;
 
   // Split the line into the fields.
   // Specs say that the following fields are to put into the block:
   // 0: ReadOrder, 1: Layer, 2: Style, 3: Name, 4: MarginL, 5: MarginR,
   // 6: MarginV, 7: Effect, 8: Text
-  vector<string> fields = split(s, ",", 9);
+  std::vector<std::string> fields = split(s, ",", 9);
   if (9 < fields.size()) {
     mxwarn(boost::format(Y("Invalid format for a SSA line ('%1%') at timecode %2%: Too many fields found (%3% instead of 9). This entry will be skipped.\n"))
            % s % format_timecode(timecode * 1000000, 3) % fields.size());
@@ -219,10 +219,10 @@ xtr_ssa_c::handle_frame(memory_cptr &frame,
   // Problem is that the CodecPrivate may contain a Format: line
   // that defines a different layout. So let's account for that.
 
-  string line = "Dialogue: ";
+  std::string line = "Dialogue: ";
   int i;
   for (i = 0; i < m_ssa_format.size(); i++) {
-    string format = m_ssa_format[i];
+    std::string format = m_ssa_format[i];
 
     if (downcase(format) == "actor")
       format = "name";
@@ -252,7 +252,7 @@ xtr_ssa_c::handle_frame(memory_cptr &frame,
   }
 
   // Do the charset conversion.
-  line  = from_utf8(m_conv, line);
+  line  = m_conv->native(line);
   line += "\n";
 
   // Now store that entry.
@@ -272,7 +272,7 @@ xtr_ssa_c::finish_file() {
 
 // ------------------------------------------------------------------------
 
-xtr_usf_c::xtr_usf_c(const string &codec_id,
+xtr_usf_c::xtr_usf_c(const std::string &codec_id,
                      int64_t tid,
                      track_spec_t &tspec)
   : xtr_base_c(codec_id, tid, tspec)
@@ -292,13 +292,13 @@ xtr_usf_c::create_file(xtr_base_c *master,
   init_content_decoder(track);
 
   memory_cptr new_priv = decode_codec_private(priv);
-  m_codec_private.append((const char *)new_priv->get(), new_priv->get_size());
+  m_codec_private.append((const char *)new_priv->get_buffer(), new_priv->get_size());
 
   KaxTrackLanguage *language = FINDFIRST(&track, KaxTrackLanguage);
   if (NULL == language)
     m_language = "eng";
   else
-    m_language = string(*language);
+    m_language = std::string(*language);
 
   if (NULL != master) {
     xtr_usf_c *usf_master = dynamic_cast<xtr_usf_c *>(master);
@@ -317,9 +317,9 @@ xtr_usf_c::create_file(xtr_base_c *master,
 
   } else {
     try {
-      string end_tag           = "</USFSubtitles>";
-      string codec_private_mod = m_codec_private;
-      int end_tag_pos          = codec_private_mod.find(end_tag);
+      std::string end_tag           = "</USFSubtitles>";
+      std::string codec_private_mod = m_codec_private;
+      int end_tag_pos               = codec_private_mod.find(end_tag);
       if (0 <= end_tag_pos)
         codec_private_mod.erase(end_tag_pos, end_tag.length());
 
@@ -331,7 +331,7 @@ xtr_usf_c::create_file(xtr_base_c *master,
       m_formatter->write_header();
       m_formatter->format(codec_private_mod + "\n");
 
-    } catch (mm_io_error_c &error) {
+    } catch (mm_io_error_c &) {
       mxerror(boost::format(Y("Failed to create the file '%1%': %2% (%3%)\n")) % m_file_name % errno % strerror(errno));
 
     } catch (xml_formatter_error_c &error) {
@@ -353,7 +353,7 @@ xtr_usf_c::handle_frame(memory_cptr &frame,
   m_content_decoder.reverse(frame, CONTENT_ENCODING_SCOPE_BLOCK);
 
   usf_entry_t entry("", timecode, timecode + duration);
-  entry.m_text.append((const char *)frame->get(), frame->get_size());
+  entry.m_text.append((const char *)frame->get_buffer(), frame->get_size());
   m_entries.push_back(entry);
 }
 
@@ -362,9 +362,9 @@ xtr_usf_c::finish_track() {
   try {
     m_formatter->format((boost::format("<subtitles>\n<language code=\"%1%\"/>\n") % m_language).str());
 
-    vector<usf_entry_t>::const_iterator entry;
+    std::vector<usf_entry_t>::const_iterator entry;
     mxforeach(entry, m_entries) {
-      string text = entry->m_text;
+      std::string text = entry->m_text;
       strip(text, true);
       m_formatter->format((boost::format("<subtitle start=\"%1%\" stop=\"%2%\">")
                            % format_timecode(entry->m_start * 1000000, 3) % format_timecode(entry->m_end * 1000000, 3)).str());
