@@ -5,23 +5,21 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: xtr_wav.cpp 3984 2008-10-11 14:11:55Z mosu $
-
    extracts tracks from Matroska files into other files
 
    Written by Moritz Bunkus <moritz@bunkus.org>
    and Steve Lhomme <steve.lhomme@free.fr>.
 */
 
-#include "os.h"
+#include "common/common_pch.h"
 
 #include <matroska/KaxBlock.h>
 
-#include "common.h"
-#include "commonebml.h"
-#include "xtr_wav.h"
+#include "common/ebml.h"
+#include "common/endian.h"
+#include "extract/xtr_wav.h"
 
-xtr_wav_c::xtr_wav_c(const string &codec_id,
+xtr_wav_c::xtr_wav_c(const std::string &codec_id,
                      int64_t tid,
                      track_spec_t &tspec)
   : xtr_base_c(codec_id, tid, tspec)
@@ -71,7 +69,7 @@ xtr_wav_c::finish_file() {
 
 // ------------------------------------------------------------------------
 
-xtr_wavpack4_c::xtr_wavpack4_c(const string &codec_id,
+xtr_wavpack4_c::xtr_wavpack4_c(const std::string &codec_id,
                                int64_t tid,
                                track_spec_t &tspec)
   : xtr_base_c(codec_id, tid, tspec)
@@ -94,17 +92,17 @@ xtr_wavpack4_c::create_file(xtr_base_c *master,
 
   if ((NULL == priv) || (2 > mpriv->get_size()))
     mxerror(boost::format(Y("Track %1% with the CodecID '%2%' is missing the \"codec private\" element and cannot be extracted.\n")) % m_tid % m_codec_id);
-  memcpy(m_version, mpriv->get(), 2);
+  memcpy(m_version, mpriv->get_buffer(), 2);
 
   xtr_base_c::create_file(master, track);
 
   m_channels = kt_get_a_channels(track);
 
   if ((0 != kt_get_max_blockadd_id(track)) && (0 != m_extract_blockadd_level)) {
-    string corr_name = m_file_name;
-    size_t pos       = corr_name.rfind('.');
+    std::string corr_name = m_file_name;
+    size_t pos            = corr_name.rfind('.');
 
-    if ((string::npos != pos) && (0 != pos))
+    if ((std::string::npos != pos) && (0 != pos))
       corr_name.erase(pos + 1);
     corr_name += "wvc";
 
@@ -141,14 +139,14 @@ xtr_wavpack4_c::handle_frame(memory_cptr &frame,
   wv_header[15] = 0xFF;
   put_uint32_le(&wv_header[16], m_number_of_samples); // block_index
 
-  binary *mybuffer     = frame->get();
+  binary *mybuffer     = frame->get_buffer();
   int data_size        = frame->get_size();
   m_number_of_samples += get_uint32_le(mybuffer);
 
   // rest of the header:
   memcpy(&wv_header[20], mybuffer, 3 * sizeof(uint32_t));
 
-  vector<uint32_t> flags;
+  std::vector<uint32_t> flags;
 
   // support multi-track files
   if (2 < m_channels) {
