@@ -5,21 +5,18 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: gui.cpp 3373 2006-11-19 17:41:46Z mosu $
-
    A console UI for mkvinfo
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "os.h"
+#include "common/common_pch.h"
 
-#include "common.h"
-#include "mkvinfo.h"
+#include "info/mkvinfo.h"
 
 void
 console_show_element(int level,
-                     const char *text,
+                     const std::string &text,
                      int64_t position) {
   char *level_buffer;
 
@@ -27,34 +24,34 @@ console_show_element(int level,
   memset(&level_buffer[1], ' ', level);
   level_buffer[0] = '|';
   level_buffer[level] = 0;
-  mxinfo("%s+ %s", level_buffer, text);
+  mxinfo(boost::format("%1%+ %2%") % level_buffer % text);
   if ((1 < verbose) && (0 <= position))
-    mxinfo(" at " LLU, position);
+    mxinfo(boost::format(Y(" at %1%")) % position);
   mxinfo("\n");
   delete []level_buffer;
 }
 
 void
-console_show_error(const char *text) {
-  mxinfo("(%s) %s\n", NAME, text);
+console_show_error(const std::string &error) {
+  mxinfo(boost::format("(%1%) %2%\n") % NAME % error);
 }
 
 #if !defined(HAVE_QT) && !defined(HAVE_WXWIDGETS)
 void
 ui_show_element(int level,
-                const char *text,
+                const std::string &text,
                 int64_t position) {
   console_show_element(level, text, position);
 }
 
 void
-ui_show_error(const char *text) {
-  console_show_error(text);
+ui_show_error(const std::string &error) {
+  console_show_error(error);
 }
 
 void
 ui_show_progress(int percentage,
-                 const char *text) {
+                 const std::string &text) {
 }
 
 int
