@@ -5,38 +5,32 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: gui.cpp 3009 2005-08-03 12:41:20Z mosu $
-
    A GUI for mkvinfo
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "config.h"
+#include "common/os.h"
 
-#ifdef HAVE_WXWINDOWS
+#ifdef HAVE_WXWIDGETS
 
-#include "wx/wx.h"
-#include "wx/treectrl.h"
-#include "wx/dnd.h"
+#include "common/wx.h"
+#include "common/treectrl.h"
+#include "common/dnd.h"
 
 #include <ebml/EbmlVersion.h>
 #include <matroska/KaxVersion.h>
 
-#include "common.h"
-#include "mkvinfo.h"
+#include "common/common_pch.h"
 #if !defined(SYS_WINDOWS)
-#include "matroska.xpm"
+#include "common/matroska.xpm"
 #endif
-#include "wxcommon.h"
+#include "common/wx.h"
+#include "info/mkvinfo.h"
 
 using namespace libebml;
 using namespace libmatroska;
 
-#if ! wxCHECK_VERSION(2,4,2)
-# define wxTreeItemIdValue long
-#endif
-
 mi_frame *frame;
 
 enum {
@@ -50,19 +44,14 @@ enum {
 
 bool
 mi_app::OnInit() {
-  string initial_file;
-  vector<string> args;
+  std::string initial_file;
+  std::vector<std::string> args;
 
   setup();
 
-#if WXUNICODE
   int i;
-
   for (i = 1; i < argc; i++)
-    args.push_back(string(wxMB(wxString(argv[i]))));
-#else
-  args = command_line_utf8(argc, argv);
-#endif
+    args.push_back(std::string(wxMB(wxString(argv[i]))));
 
   parse_args(args, initial_file);
 
@@ -148,12 +137,9 @@ mi_frame::mi_frame(const wxString &title,
 
 void
 mi_frame::open_file(wxString file_name) {
-  string cfile_name;
-#if WXUNICODE
-  cfile_name = from_utf8(cc_local_utf8, wxMB(file_name));
-#else
+  std::string cfile_name;
+
   cfile_name = wxMB(file_name);
-#endif
   tree->DeleteAllItems();
   item_ids[0] = tree->AddRoot(file_name);
   last_percent = -1;
@@ -353,7 +339,7 @@ mi_frame::on_help_about(wxCommandEvent &WXUNUSED(event)) {
                  "<moritz@bunkus.org>.\nSources and the latest binaries are "
                  "always available at\nhttp://www.bunkus.org/videotools/"
                  "mkvtoolnix/"),
-             wxCS2WS(EbmlCodeVersion), wxCS2WS(KaxCodeVersion));
+             wxUCS(EbmlCodeVersion), wxUCS(KaxCodeVersion));
   wxMessageBox(msg, wxT("About mkvinfo"), wxOK | wxICON_INFORMATION, this);
 }
 
@@ -407,4 +393,4 @@ IMPLEMENT_APP(mi_app)
 IMPLEMENT_APP_NO_MAIN(mi_app)
 #endif
 
-#endif // HAVE_WXWINDOWS
+#endif // HAVE_WXWIDGETS
