@@ -10,7 +10,7 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "common/os.h"
+#include "common/common_pch.h"
 
 #include <errno.h>
 #include <ctype.h>
@@ -29,18 +29,15 @@
 
 #include <algorithm>
 #include <iostream>
-#include <map>
 #include <typeinfo>
-#include <vector>
 
-extern "C" {
 #include <avilib.h>
-}
 
 #include <ebml/EbmlHead.h>
 #include <ebml/EbmlSubHead.h>
 #include <ebml/EbmlStream.h>
 #include <ebml/EbmlVoid.h>
+#include <ebml/EbmlCrc32.h>
 #include <matroska/FileKax.h>
 
 #include <matroska/KaxAttached.h>
@@ -72,10 +69,8 @@ extern "C" {
 #include "common/chapters/chapters.h"
 #include "common/checksums.h"
 #include "common/command_line.h"
-#include "common/common.h"
 #include "common/ebml.h"
 #include "common/endian.h"
-#include "common/locale.h"
 #include "common/matroska.h"
 #include "common/mm_io.h"
 #include "common/strings/editing.h"
@@ -231,10 +226,10 @@ _show_unknown_element(EbmlStream *es,
 
   int i;
   std::string element_id;
-  for (i = e->Generic().GlobalId.Length - 1; 0 <= i; --i)
-    element_id += (s_bf_show_unknown_element % ((e->Generic().GlobalId.Value >> (i * 8)) & 0xff)).str();
+  for (i = EBML_ID_LENGTH(EbmlId(*e)) - 1; 0 <= i; --i)
+    element_id += (s_bf_show_unknown_element % ((EBML_ID_VALUE(EbmlId(*e)) >> (i * 8)) & 0xff)).str();
 
-  std::string s = (BF_SHOW_UNKNOWN_ELEMENT % e->Generic().DebugName % element_id % (e->GetSize() + e->HeadSize())).str();
+  std::string s = (BF_SHOW_UNKNOWN_ELEMENT % EBML_NAME(e) % element_id % (e->GetSize() + e->HeadSize())).str();
   _show_element(e, es, true, level, s);
 }
 
@@ -260,7 +255,7 @@ _show_element(EbmlElement *l,
       show_unknown_element((*m)[i], level + 1);
   }
 
-  l->SkipData(*es, l->Generic().Context);
+  l->SkipData(*es, EBML_CONTEXT(l));
 }
 
 inline void
@@ -456,18 +451,32 @@ format_binary(EbmlBinary &bin,
                                  EbmlElement *&l4, \
                                  EbmlElement *&l5, \
                                  EbmlElement *&l6)
-#define handle2(f, args...) \
-  handle_##f(in, es, upper_lvl_el, l1, l2, l3, l4, l5, l6, ##args)
-#define def_handle2(f, args...) handle_##f(mm_io_c *&in, \
-                                           EbmlStream *&es, \
-                                           int &upper_lvl_el, \
-                                           EbmlElement *&l1, \
-                                           EbmlElement *&l2, \
-                                           EbmlElement *&l3, \
-                                           EbmlElement *&l4, \
-                                           EbmlElement *&l5, \
-                                           EbmlElement *&l6, \
-                                           ##args)
+
+#define handle2(f, arg1) \
+  handle_##f(in, es, upper_lvl_el, l1, l2, l3, l4, l5, l6, arg1)
+#define handle3(f, arg1, arg2) \
+  handle_##f(in, es, upper_lvl_el, l1, l2, l3, l4, l5, l6, arg1, arg2)
+#define def_handle2(f, arg1) handle_##f(mm_io_c *&in,      \
+                                        EbmlStream *&es,   \
+                                        int &upper_lvl_el, \
+                                        EbmlElement *&l1,  \
+                                        EbmlElement *&l2,  \
+                                        EbmlElement *&l3,  \
+                                        EbmlElement *&l4,  \
+                                        EbmlElement *&l5,  \
+                                        EbmlElement *&l6,  \
+                                        arg1)
+#define def_handle3(f, arg1, arg2) handle_##f(mm_io_c *&in,      \
+                                              EbmlStream *&es,   \
+                                              int &upper_lvl_el, \
+                                              EbmlElement *&l1,  \
+                                              EbmlElement *&l2,  \
+                                              EbmlElement *&l3,  \
+                                              EbmlElement *&l4,  \
+                                              EbmlElement *&l5,  \
+                                              EbmlElement *&l6,  \
+                                              arg1,              \
+                                              arg2)
 
 void
 def_handle(chaptertranslate) {
@@ -502,7 +511,7 @@ def_handle(info) {
 
   upper_lvl_el   = 0;
   EbmlMaster *m1 = static_cast<EbmlMaster *>(l1);
-  read_master(m1, es, l1->Generic().Context, upper_lvl_el, l3);
+  read_master(m1, es, EBML_CONTEXT(l1), upper_lvl_el, l3);
 
   int i1;
   for (i1 = 0; i1 < m1->ListSize(); i1++) {
@@ -876,7 +885,7 @@ def_handle(tracks) {
 
   upper_lvl_el = 0;
   EbmlMaster *m1 = static_cast<EbmlMaster *>(l1);
-  read_master(m1, es, l1->Generic().Context, upper_lvl_el, l3);
+  read_master(m1, es, EBML_CONTEXT(l1), upper_lvl_el, l3);
 
   int i1;
   for (i1 = 0; i1 < m1->ListSize(); i1++) {
@@ -1095,7 +1104,7 @@ def_handle(seek_head) {
 
   upper_lvl_el   = 0;
   EbmlMaster *m1 = static_cast<EbmlMaster *>(l1);
-  read_master(m1, es, l1->Generic().Context, upper_lvl_el, l3);
+  read_master(m1, es, EBML_CONTEXT(l1), upper_lvl_el, l3);
 
   int i1;
   for (i1 = 0; i1 < m1->ListSize(); i1++) {
@@ -1116,15 +1125,15 @@ def_handle(seek_head) {
           show_element(l3, 3,
                        boost::format(Y("Seek ID:%1% (%2%)"))
                        % to_hex(seek_id.GetBuffer(), seek_id.GetSize())
-                       % (  KaxInfo::ClassInfos.GlobalId        == id ? "KaxInfo"
-                          : KaxCluster::ClassInfos.GlobalId     == id ? "KaxCluster"
-                          : KaxTracks::ClassInfos.GlobalId      == id ? "KaxTracks"
-                          : KaxCues::ClassInfos.GlobalId        == id ? "KaxCues"
-                          : KaxAttachments::ClassInfos.GlobalId == id ? "KaxAttachments"
-                          : KaxChapters::ClassInfos.GlobalId    == id ? "KaxChapters"
-                          : KaxTags::ClassInfos.GlobalId        == id ? "KaxTags"
-                          : KaxSeekHead::ClassInfos.GlobalId    == id ? "KaxSeekHead"
-                          :                                             "unknown"));
+                       % (  EBML_ID(KaxInfo)        == id ? "KaxInfo"
+                          : EBML_ID(KaxCluster)     == id ? "KaxCluster"
+                          : EBML_ID(KaxTracks)      == id ? "KaxTracks"
+                          : EBML_ID(KaxCues)        == id ? "KaxCues"
+                          : EBML_ID(KaxAttachments) == id ? "KaxAttachments"
+                          : EBML_ID(KaxChapters)    == id ? "KaxChapters"
+                          : EBML_ID(KaxTags)        == id ? "KaxTags"
+                          : EBML_ID(KaxSeekHead)    == id ? "KaxSeekHead"
+                          :                                 "unknown"));
 
         } else if (is_id(l3, KaxSeekPosition)) {
           KaxSeekPosition &seek_pos = static_cast<KaxSeekPosition &>(*l3);
@@ -1152,7 +1161,7 @@ def_handle(cues) {
 
   upper_lvl_el   = 0;
   EbmlMaster *m1 = static_cast<EbmlMaster *>(l1);
-  read_master(m1, es, l1->Generic().Context, upper_lvl_el, l3);
+  read_master(m1, es, EBML_CONTEXT(l1), upper_lvl_el, l3);
 
   int i1;
   for (i1 = 0; i1 < m1->ListSize(); i1++) {
@@ -1247,7 +1256,7 @@ def_handle(attachments) {
 
   upper_lvl_el   = 0;
   EbmlMaster *m1 = static_cast<EbmlMaster *>(l1);
-  read_master(m1, es, l1->Generic().Context, upper_lvl_el, l3);
+  read_master(m1, es, EBML_CONTEXT(l1), upper_lvl_el, l3);
 
   int i1;
   for (i1 = 0; i1 < m1->ListSize(); i1++) {
@@ -1606,7 +1615,7 @@ def_handle2(simple_block,
 }
 
 void
-def_handle2(cluster,
+def_handle3(cluster,
             KaxCluster *&cluster,
             int64_t file_size) {
   cluster = (KaxCluster *)l1;
@@ -1616,7 +1625,7 @@ def_handle2(cluster,
 
   upper_lvl_el   = 0;
   EbmlMaster *m1 = static_cast<EbmlMaster *>(l1);
-  read_master(m1, es, l1->Generic().Context, upper_lvl_el, l3);
+  read_master(m1, es, EBML_CONTEXT(l1), upper_lvl_el, l3);
 
   int i1;
   for (i1 = 0; i1 < m1->ListSize(); i1++) {
@@ -1663,13 +1672,13 @@ handle_elements_rec(EbmlStream *es,
   bool found = false;
   int elt_idx;
   for (elt_idx = 0; NULL != mapping[elt_idx].name; ++elt_idx)
-    if (e->Generic().GlobalId == mapping[elt_idx].id) {
+    if (EbmlId(*e) == mapping[elt_idx].id) {
       found = true;
       break;
     }
 
   if (!found) {
-    show_element(e, level, BF_HANDLE_ELEMENTS_REC_UNKNOWN % e->Generic().DebugName);
+    show_element(e, level, BF_HANDLE_ELEMENTS_REC_UNKNOWN % EBML_NAME(e));
     return;
   }
 
@@ -1719,7 +1728,7 @@ def_handle(chapters) {
 
   upper_lvl_el   = 0;
   EbmlMaster *m1 = static_cast<EbmlMaster *>(l1);
-  read_master(m1, es, l1->Generic().Context, upper_lvl_el, l3);
+  read_master(m1, es, EBML_CONTEXT(l1), upper_lvl_el, l3);
 
   int i1;
   for (i1 = 0; i1 < m1->ListSize(); i1++)
@@ -1732,7 +1741,7 @@ def_handle(tags) {
 
   upper_lvl_el   = 0;
   EbmlMaster *m1 = static_cast<EbmlMaster *>(l1);
-  read_master(m1, es, l1->Generic().Context, upper_lvl_el, l3);
+  read_master(m1, es, EBML_CONTEXT(l1), upper_lvl_el, l3);
 
   int i1;
   for (i1 = 0; i1 < m1->ListSize(); i1++)
@@ -1747,7 +1756,7 @@ handle_ebml_head(EbmlElement *l0,
 
   while (in_parent(l0)) {
     int upper_lvl_el = 0;
-    EbmlElement *e   = es->FindNextElement(l0->Generic().Context, upper_lvl_el, 0xFFFFFFFFL, true);
+    EbmlElement *e   = es->FindNextElement(EBML_CONTEXT(l0), upper_lvl_el, 0xFFFFFFFFL, true);
 
     if (NULL == e)
       return;
@@ -1778,7 +1787,7 @@ handle_ebml_head(EbmlElement *l0,
     else
       show_unknown_element(e, 1);
 
-    e->SkipData(*es, e->Generic().Context);
+    e->SkipData(*es, EBML_CONTEXT(e));
     delete e;
   }
 }
@@ -1808,7 +1817,7 @@ process_file(const std::string &file_name) {
     EbmlStream *es = new EbmlStream(*in);
 
     // Find the EbmlHead element. Must be the first one.
-    l0 = es->FindNextID(EbmlHead::ClassInfos, 0xFFFFFFFFL);
+    l0 = es->FindNextID(EBML_INFO(EbmlHead), 0xFFFFFFFFL);
     if (NULL == l0) {
       show_error(Y("No EBML head found."));
       delete es;
@@ -1817,12 +1826,12 @@ process_file(const std::string &file_name) {
     }
 
     handle_ebml_head(l0, in, es);
-    l0->SkipData(*es, l0->Generic().Context);
+    l0->SkipData(*es, EBML_CONTEXT(l0));
     delete l0;
 
     while (1) {
       // Next element must be a segment
-      l0 = es->FindNextID(KaxSegment::ClassInfos, 0xFFFFFFFFFFFFFFFFLL);
+      l0 = es->FindNextID(EBML_INFO(KaxSegment), 0xFFFFFFFFFFFFFFFFLL);
       if (NULL == l0) {
         show_error(Y("No segment/level 0 element found."));
         return false;
@@ -1838,13 +1847,13 @@ process_file(const std::string &file_name) {
 
       show_element(l0, 0, boost::format(Y("Next level 0 element is not a segment but %1%")) % typeid(*l0).name());
 
-      l0->SkipData(*es, l0->Generic().Context);
+      l0->SkipData(*es, EBML_CONTEXT(l0));
       delete l0;
     }
 
     upper_lvl_el = 0;
     // We've got our segment, so let's find the tracks
-    l1 = es->FindNextElement(l0->Generic().Context, upper_lvl_el, 0xFFFFFFFFL, true);
+    l1 = es->FindNextElement(EBML_CONTEXT(l0), upper_lvl_el, 0xFFFFFFFFL, true);
 
     while ((NULL != l1) && (0 >= upper_lvl_el)) {
       if (is_id(l1, KaxInfo))
@@ -1866,7 +1875,7 @@ process_file(const std::string &file_name) {
 
           return true;
         }
-        handle2(cluster, cluster, file_size);
+        handle3(cluster, cluster, file_size);
 
       } else if (is_id(l1, KaxCues))
         handle(cues);
@@ -1905,9 +1914,9 @@ process_file(const std::string &file_name) {
 
       }
 
-      l1->SkipData(*es, l1->Generic().Context);
+      l1->SkipData(*es, EBML_CONTEXT(l1));
       delete l1;
-      l1 = es->FindNextElement(l0->Generic().Context, upper_lvl_el, 0xFFFFFFFFL, true);
+      l1 = es->FindNextElement(EBML_CONTEXT(l0), upper_lvl_el, 0xFFFFFFFFL, true);
 
     } // while (l1 != NULL)
 
