@@ -10,7 +10,7 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "config.h"
+#include "common/os.h"
 
 #ifdef HAVE_WXWIDGETS
 
@@ -22,22 +22,19 @@
 #include <ebml/EbmlVersion.h>
 #include <matroska/KaxVersion.h>
 
-#include "common.h"
-#include "mkvinfo.h"
-#include "translation.h"
-#include "wxwidgets_ui.h"
+#include "common/common_pch.h"
+#include "common/translation.h"
+#include "common/version.h"
+#include "common/wx.h"
+#include "info/wxwidgets_ui.h"
 #if !defined(SYS_WINDOWS)
-#include "matroska.xpm"
+#include "info/matroska.xpm"
 #endif
-#include "wxcommon.h"
+#include "info/mkvinfo.h"
 
 using namespace libebml;
 using namespace libmatroska;
 
-#if ! wxCHECK_VERSION(2,4,2)
-# define wxTreeItemIdValue long
-#endif
-
 static mi_frame *frame;
 
 enum {
@@ -72,22 +69,17 @@ mi_app::get_ui_locale() {
 
 bool
 mi_app::OnInit() {
-  string initial_file;
-  vector<string> args;
+  std::string initial_file;
+  std::vector<std::string> args;
 
   wxConfigBase *cfg = new wxConfig(wxT("mkvmergeGUI"));
   wxConfigBase::Set(cfg);
 
   setup(get_ui_locale());
 
-#if WXUNICODE
   int i;
-
   for (i = 1; i < argc; i++)
-    args.push_back(string(wxMB(wxString(argv[i]))));
-#else
-  args = command_line_utf8(argc, argv);
-#endif
+    args.push_back(std::string(wxMB(wxString(argv[i]))));
 
   parse_args(args, initial_file);
 
@@ -162,7 +154,7 @@ mi_frame::mi_frame(const wxString &title,
 
 void
 mi_frame::open_file(wxString file_name) {
-  string cfile_name;
+  std::string cfile_name;
 
   cfile_name = wxMB(file_name);
   tree->DeleteAllItems();
@@ -359,7 +351,7 @@ mi_frame::on_help_about(wxCommandEvent &WXUNUSED(event)) {
                "<moritz@bunkus.org>.\nSources and the latest binaries are "
                "always available at\nhttp://www.bunkus.org/videotools/"
                "mkvtoolnix/"),
-             wxUCS(VERSIONINFO), wxCS2WS(EbmlCodeVersion), wxCS2WS(KaxCodeVersion));
+             wxUCS(get_version_info("mkvinfo GUI")), wxUCS(EbmlCodeVersion), wxUCS(KaxCodeVersion));
   wxMessageBox(msg, Z("About mkvinfo"), wxOK | wxICON_INFORMATION, this);
 }
 
@@ -439,6 +431,10 @@ ui_show_progress(int percentage,
 int
 ui_run(int argc,
        char **argv) {
+#if defined(SYS_WINDOWS)
+  FreeConsole();
+#endif
+
   wxEntry(argc, argv);
   return 0;
 }
