@@ -6,14 +6,12 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: flac_common.cpp 3873 2008-09-07 11:05:43Z mosu $
-
    FLAC helper functions
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "config.h"
+#include "common/common_pch.h"
 
 #if defined(HAVE_FLAC_FORMAT_H)
 
@@ -26,9 +24,8 @@
 # undef LEGACY_FLAC
 #endif
 
-#include "bit_cursor.h"
-#include "common.h"
-#include "flac_common.h"
+#include "common/bit_cursor.h"
+#include "input/flac_common.h"
 
 static bool
 flac_skip_utf8(bit_cursor_c &bits,
