@@ -11,20 +11,16 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "os.h"
+#include "common/common_pch.h"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
 #include <ogg/ogg.h>
 #include <vorbis/codec.h>
 
-#include "common.h"
-#include "flac_common.h"
-#include "matroska.h"
-#include "output_control.h"
-#include "pr_generic.h"
-#include "r_flac.h"
+#include "common/matroska.h"
+#include "input/flac_common.h"
+#include "input/r_flac.h"
+#include "merge/output_control.h"
+#include "merge/pr_generic.h"
 
 #define BUFFER_SIZE 4096
 
@@ -189,7 +185,7 @@ flac_reader_c::flac_reader_c(track_info_c &_ti)
   header(NULL) {
 
   try {
-    file      = new mm_file_io_c(ti.fname);
+    file      = new mm_file_io_c(m_ti.m_fname);
     file_size = file->get_size();
   } catch (...) {
     throw error_c(Y("flac_reader: Could not open the source file."));
@@ -198,7 +194,7 @@ flac_reader_c::flac_reader_c(track_info_c &_ti)
   if (g_identifying)
     return;
 
-  mxinfo_fn(ti.fname, Y("Using the FLAC demultiplexer.\n"));
+  mxinfo_fn(m_ti.m_fname, Y("Using the FLAC demultiplexer.\n"));
 
   if (!parse_file())
     throw error_c(Y("flac_reader: Could not read all header packets."));
@@ -237,8 +233,8 @@ flac_reader_c::create_packetizer(int64_t) {
   if (NPTZR() != 0)
     return;
 
-  add_packetizer(new flac_packetizer_c(this, ti, header, header_size));
-  mxinfo_tid(ti.fname, 0, Y("Using the FLAC output module.\n"));
+  add_packetizer(new flac_packetizer_c(this, m_ti, header, header_size));
+  mxinfo_tid(m_ti.m_fname, 0, Y("Using the FLAC output module.\n"));
 }
 
 bool
@@ -305,7 +301,7 @@ flac_reader_c::parse_file() {
   mxverb(2, boost::format("flac_reader: extract->metadata, result: %1%, mdp: %2%, num blocks: %3%\n") % result % metadata_parsed % blocks.size());
 
   if (!metadata_parsed)
-    mxerror_fn(ti.fname, Y("No metadata block found. This file is broken.\n"));
+    mxerror_fn(m_ti.m_fname, Y("No metadata block found. This file is broken.\n"));
 
 #ifdef LEGACY_FLAC
   FLAC__seekable_stream_decoder_get_decode_position(decoder, &u);
@@ -384,7 +380,10 @@ flac_reader_c::parse_file() {
 #endif  // HAVE_FLAC_DECODER_SKIP
   }
 
-  mxinfo(Y("+-> Pre-parsing FLAC file: 100%%\n"));
+  if (100 != old_progress)
+    mxinfo(Y("+-> Pre-parsing FLAC file: 100%\n"));
+  else
+    mxinfo("\n");
 
   if ((blocks.size() == 0) || (blocks[0].type != FLAC_BLOCK_TYPE_HEADERS))
     mxerror(Y("flac_reader: Could not read all header packets.\n"));
@@ -567,7 +566,7 @@ flac_reader_c::probe_file(mm_io_c *io,
     return 0;
   try {
     io->setFilePointer(0, seek_beginning);
-    if (4 != io->read(data, 4) != 4)
+    if (io->read(data, 4) != 4)
       return 0;
     io->setFilePointer(0, seek_beginning);
   } catch (...) {
