@@ -6,8 +6,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_flac.h 3830 2008-08-19 14:52:12Z mosu $
-
    class definitions for the raw FLAC stream reader
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
@@ -16,12 +14,12 @@
 #ifndef __R_FLAC_H
 #define __R_FLAC_H
 
-#include "os.h"
+#include "common/common_pch.h"
 
-#include "mm_io.h"
+#include "common/mm_io.h"
+#include "merge/pr_generic.h"
 
 #if defined(HAVE_FLAC_FORMAT_H)
-#include <vector>
 
 #include <FLAC/export.h>
 #if !defined(FLAC_API_VERSION_CURRENT) || FLAC_API_VERSION_CURRENT < 8
@@ -35,7 +33,7 @@
 # include <FLAC/stream_decoder.h>
 #endif
 
-#include "p_flac.h"
+#include "output/p_flac.h"
 
 #define FLAC_BLOCK_TYPE_HEADERS 0
 #define FLAC_BLOCK_TYPE_DATA    1
@@ -53,8 +51,8 @@ private:
   int64_t samples, file_size;
   unsigned char *header;
   int header_size;
-  vector<flac_block_t> blocks;
-  vector<flac_block_t>::iterator current_block;
+  std::vector<flac_block_t> blocks;
+  std::vector<flac_block_t>::iterator current_block;
   FLAC__StreamMetadata_StreamInfo stream_info;
 
 public:
@@ -112,5 +110,4 @@ public:
 
 #endif // HAVE_FLAC_FORMAT_H
 
-
 #endif  // __R_FLAC_H
