@@ -15,16 +15,15 @@
 #ifndef __R_MATROSKA_H
 #define __R_MATROSKA_H
 
-#include "common/os.h"
+#include "common/common_pch.h"
 
 #include <boost/logic/tribool.hpp>
-#include <map>
-#include <vector>
 
-#include "common/common.h"
 #include "common/compression.h"
 #include "common/error.h"
+#include "common/kax_file.h"
 #include "common/mm_io.h"
+#include "common/mpeg4_p10.h"
 #include "merge/pr_generic.h"
 
 #include <ebml/EbmlUnicodeString.h>
@@ -89,7 +88,7 @@ struct kax_track_t {
 
   bool ignore_duration_hack;
 
-  memory_cptr first_frame_data;
+  std::vector<memory_cptr> first_frames_data;
 
   kax_track_t()
     : tnum(0)
@@ -147,6 +146,7 @@ struct kax_track_t {
   void handle_packetizer_pixel_cropping();
   void handle_packetizer_stereo_mode();
 };
+typedef counted_ptr<kax_track_t> kax_track_cptr;
 
 class kax_reader_c: public generic_reader_c {
 private:
@@ -158,35 +158,31 @@ private:
     dl1t_tracks,
   };
 
-  int act_wchar;
+  std::vector<kax_track_cptr> m_tracks;
+  std::map<generic_packetizer_c *, kax_track_t *> m_ptzr_to_track_map;
 
-  std::vector<kax_track_t *> tracks;
-  std::map<generic_packetizer_c *, kax_track_t *> ptzr_to_track_map;
+  int64_t m_tc_scale;
 
-  int64_t tc_scale;
-  int64_t cluster_tc;
+  mm_io_cptr m_in;
+  kax_file_cptr m_in_file;
+  int64_t m_file_size;
 
-  mm_io_c *in;
-  int64_t file_size;
+  counted_ptr<EbmlStream> m_es;
 
-  EbmlStream *es;
-  EbmlElement *saved_l1, *saved_l2, *segment;
-  KaxCluster *cluster;
+  int64_t m_segment_duration, m_last_timecode, m_first_timecode;
+  std::string m_title;
 
-  int64_t segment_duration;
-  int64_t last_timecode, first_timecode;
-  std::string title;
-
-  // typedef std::map<deferred_l1_type_e, counted_ptr<std::vector<int64_t> > > deferred_positions_t;
   typedef std::map<deferred_l1_type_e, std::vector<int64_t> > deferred_positions_t;
-  deferred_positions_t deferred_l1_positions, handled_l1_positions;
+  deferred_positions_t m_deferred_l1_positions, m_handled_l1_positions;
 
-  std::string writing_app, muxing_app;
-  int64_t writing_app_ver;
+  std::string m_writing_app, m_muxing_app;
+  int64_t m_writing_app_ver;
 
   int64_t m_attachment_id;
 
-  KaxTags *m_tags;
+  counted_ptr<KaxTags> m_tags;
+
+  file_status_e m_file_status;
 
 public:
   kax_reader_c(track_info_c &_ti) throw (error_c);
@@ -206,21 +202,50 @@ public:
 protected:
   virtual void init_passthrough_packetizer(kax_track_t *t);
   virtual void set_packetizer_headers(kax_track_t *t);
-  virtual void read_first_frame(kax_track_t *t);
+  virtual void read_first_frames(kax_track_t *t, unsigned num_wanted = 1);
   virtual kax_track_t *new_kax_track();
   virtual kax_track_t *find_track_by_num(uint64_t num, kax_track_t *c = NULL);
   virtual kax_track_t *find_track_by_uid(uint64_t uid, kax_track_t *c = NULL);
+
+  virtual bool verify_acm_audio_track(kax_track_t *t);
+  virtual bool verify_flac_audio_track(kax_track_t *t);
+  virtual bool verify_vorbis_audio_track(kax_track_t *t);
+  virtual void verify_audio_track(kax_track_t *t);
+  virtual bool verify_mscomp_video_track(kax_track_t *t);
+  virtual bool verify_theora_video_track(kax_track_t *t);
+  virtual void verify_video_track(kax_track_t *t);
+  virtual bool verify_kate_subtitle_track(kax_track_t *t);
+  virtual bool verify_vobsub_subtitle_track(kax_track_t *t);
+  virtual void verify_subtitle_track(kax_track_t *t);
+  virtual void verify_button_track(kax_track_t *t);
   virtual void verify_tracks();
+
   virtual int packets_available();
   virtual void handle_attachments(mm_io_c *io, EbmlElement *l0, int64_t pos);
   virtual void handle_chapters(mm_io_c *io, EbmlElement *l0, int64_t pos);
   virtual void handle_tags(mm_io_c *io, EbmlElement *l0, int64_t pos);
   virtual void process_global_tags();
 
+  virtual bool unlace_vorbis_private_data(kax_track_t *t, unsigned char *buffer, int size);
+
   virtual void create_video_packetizer(kax_track_t *t, track_info_c &nti);
   virtual void create_audio_packetizer(kax_track_t *t, track_info_c &nti);
   virtual void create_subtitle_packetizer(kax_track_t *t, track_info_c &nti);
   virtual void create_button_packetizer(kax_track_t *t, track_info_c &nti);
+
+  virtual void create_aac_audio_packetizer(kax_track_t *t, track_info_c &nti);
+  virtual void create_ac3_audio_packetizer(kax_track_t *t, track_info_c &nti);
+  virtual void create_dts_audio_packetizer(kax_track_t *t, track_info_c &nti);
+#if defined(HAVE_FLAC_FORMAT_H)
+  virtual void create_flac_audio_packetizer(kax_track_t *t, track_info_c &nti);
+#endif
+  virtual void create_mp3_audio_packetizer(kax_track_t *t, track_info_c &nti);
+  virtual void create_pcm_audio_packetizer(kax_track_t *t, track_info_c &nti);
+  virtual void create_tta_audio_packetizer(kax_track_t *t, track_info_c &nti);
+  virtual void create_vorbis_audio_packetizer(kax_track_t *t, track_info_c &nti);
+  virtual void create_wavpack_audio_packetizer(kax_track_t *t, track_info_c &nti);
+
+  virtual void create_mpeg4_p10_video_packetizer(kax_track_t *t, track_info_c &nti);
   virtual void create_mpeg4_p10_es_video_packetizer(kax_track_t *t, track_info_c &nti);
 
   virtual void read_headers_info(EbmlElement *&l1, EbmlElement *&l2, int &upper_lvl_el);
@@ -229,7 +254,12 @@ protected:
   virtual void read_headers_track_video(kax_track_t *&track, KaxTrackVideo *&ktvideo);
   virtual void read_headers_tracks(mm_io_c *io, EbmlElement *l0, int64_t position);
   virtual void read_headers_seek_head(EbmlElement *&l0, EbmlElement *&l1);
-  virtual int  read_headers();
+  virtual bool read_headers();
+
+  virtual void process_simple_block(KaxCluster *cluster, KaxSimpleBlock *block_simple);
+  virtual void process_block_group(KaxCluster *cluster, KaxBlockGroup *block_group);
+
+  virtual mpeg4::p10::avc_es_parser_cptr parse_first_mpeg4_p10_frame(kax_track_t *t, track_info_c &nti);
 
   void init_l1_position_storage(deferred_positions_t &storage);
   virtual bool has_deferred_element_been_processed(deferred_l1_type_e type, int64_t position);
