@@ -14,7 +14,7 @@
 #ifndef __R_MPEG_ES_H
 #define __R_MPEG_ES_H
 
-#include "common/os.h"
+#include "common/common_pch.h"
 
 #include "common/dts.h"
 #include "common/mpeg1_2.h"
@@ -32,7 +32,7 @@ private:
   mm_io_c *io;
   int64_t bytes_processed, size;
 
-  int version, width, height, dwidth, dheight;
+  int version, interlaced, width, height, dwidth, dheight;
   double frame_rate, aspect_ratio;
 
 public:
