@@ -11,8 +11,7 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "common/os.h"
-#include "common/os.h"
+#include "common/common_pch.h"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -24,20 +23,16 @@
 #include <time.h>
 #endif
 
-extern "C" {                    // for BITMAPINFOHEADER
-#include "avilib.h"
-}
+#include <avilib.h>   // for BITMAPINFOHEADER
 
 #include "common/aac.h"
 #include "common/chapters/chapters.h"
-#include "common/common.h"
 #include "common/ebml.h"
 #include "common/endian.h"
 #include "common/hacks.h"
 #include "common/iso639.h"
 #include "common/matroska.h"
 #include "common/mpeg4_p2.h"
-#include "common/locale.h"
 #include "common/ogmstreams.h"
 #include "input/r_ogm.h"
 #include "input/r_ogm_flac.h"
@@ -302,7 +297,7 @@ ogm_reader_c::ogm_reader_c(track_info_c &_ti)
   generic_reader_c(_ti) {
 
   try {
-    io        = new mm_file_io_c(ti.fname);
+    io        = new mm_file_io_c(m_ti.m_fname);
     file_size = io->get_size();
   } catch (...) {
     throw error_c(Y("ogm_reader: Could not open the source file."));
@@ -313,7 +308,7 @@ ogm_reader_c::ogm_reader_c(track_info_c &_ti)
   ogg_sync_init(&oy);
 
   if (verbose)
-    mxinfo_fn(ti.fname, Y("Using the OGG/OGM demultiplexer.\n"));
+    mxinfo_fn(m_ti.m_fname, Y("Using the OGG/OGM demultiplexer.\n"));
 
   if (read_headers() <= 0)
     throw error_c(Y("ogm_reader: Could not read all header packets."));
@@ -356,11 +351,11 @@ ogm_reader_c::read_page(ogg_page *og) {
     if (0 >= np) {
       // np < 0 is the error case. Should not happen with local OGG files.
       if (0 > np)
-        mxwarn_fn(ti.fname, Y("Could not find the next Ogg page. This indicates a damaged Ogg/Ogm file. Will try to continue.\n"));
+        mxwarn_fn(m_ti.m_fname, Y("Could not find the next Ogg page. This indicates a damaged Ogg/Ogm file. Will try to continue.\n"));
 
       buf = (unsigned char *)ogg_sync_buffer(&oy, BUFFER_SIZE);
       if (!buf)
-        mxerror_fn(ti.fname, Y("ogg_sync_buffer failed\n"));
+        mxerror_fn(m_ti.m_fname, Y("ogg_sync_buffer failed\n"));
 
       if (0 >= (nread = io->read(buf, BUFFER_SIZE)))
         return 0;
@@ -387,19 +382,19 @@ ogm_reader_c::create_packetizer(int64_t tid) {
   if (!dmx->in_use)
     return;
 
-  ti.private_data = NULL;
-  ti.private_size = 0;
-  ti.id           = tid;
-  ti.language     = dmx->language;
-  ti.track_name   = dmx->title;
+  m_ti.m_private_data = NULL;
+  m_ti.m_private_size = 0;
+  m_ti.m_id           = tid;
+  m_ti.m_language     = dmx->language;
+  m_ti.m_track_name   = dmx->title;
 
-  ptzr            = dmx->create_packetizer(ti);
+  ptzr                = dmx->create_packetizer(m_ti);
 
   if (NULL != ptzr)
-    dmx->ptzr     = add_packetizer(ptzr);
+    dmx->ptzr         = add_packetizer(ptzr);
 
-  ti.language.clear();
-  ti.track_name.clear();
+  m_ti.m_language.clear();
+  m_ti.m_track_name.clear();
 }
 
 void
@@ -449,7 +444,7 @@ ogm_reader_c::handle_new_stream(ogg_page *og) {
   ogg_packet op;
 
   if (ogg_stream_init(&os, ogg_page_serialno(og))) {
-    mxwarn_fn(ti.fname, boost::format(Y("ogg_stream_init for stream number %1% failed. Will try to continue and ignore this stream.\n")) % sdemuxers.size());
+    mxwarn_fn(m_ti.m_fname, boost::format(Y("ogg_stream_init for stream number %1% failed. Will try to continue and ignore this stream.\n")) % sdemuxers.size());
     return;
   }
 
@@ -476,7 +471,7 @@ ogm_reader_c::handle_new_stream(ogg_page *og) {
   else if ((4 <= op.bytes) && !strncmp((char *)op.packet, "fLaC", 4)) {
 #if !defined(HAVE_FLAC_FORMAT_H)
     if (demuxing_requested('a', sdemuxers.size()))
-      mxerror_fn(ti.fname, Y("mkvmerge has not been compiled with FLAC support but handling of this stream has been requested.\n"));
+      mxerror_fn(m_ti.m_fname, Y("mkvmerge has not been compiled with FLAC support but handling of this stream has been requested.\n"));
 
     else {
       dmx         = new ogm_demuxer_c(this);
@@ -521,7 +516,7 @@ ogm_reader_c::handle_new_stream(ogg_page *og) {
         dmx = new ogm_a_aac_demuxer_c(this);
 
       else
-        mxwarn_fn(ti.fname, boost::format(Y("Unknown audio stream type 0x%|1$04x|. Stream ID %2% will be ignored.\n")) % codec_id % sdemuxers.size());
+        mxwarn_fn(m_ti.m_fname, boost::format(Y("Unknown audio stream type 0x%|1$04x|. Stream ID %2% will be ignored.\n")) % codec_id % sdemuxers.size());
 
     } else if (!strncmp(sth->streamtype, "text", 4))
       dmx = new ogm_s_text_demuxer_c(this);
@@ -570,7 +565,7 @@ ogm_reader_c::process_page(ogg_page *og) {
   granulepos = ogg_page_granulepos(og);
 
   if ((-1 != granulepos) && (granulepos < dmx->last_granulepos)) {
-    mxwarn_tid(ti.fname, dmx->track_id,
+    mxwarn_tid(m_ti.m_fname, dmx->track_id,
                Y("The timecodes for this stream have been reset in the middle of the file. This is not supported. The current packet will be discarded.\n"));
     return;
   }
@@ -717,8 +712,8 @@ ogm_reader_c::identify() {
     id_result_track(i, sdemuxers[i]->get_type(), sdemuxers[i]->get_codec(), verbose_info);
   }
 
-  if (NULL != chapters)
-    id_result_chapters(count_chapter_atoms(*chapters));
+  if (NULL != m_chapters)
+    id_result_chapters(count_chapter_atoms(*m_chapters));
 }
 
 void
@@ -727,7 +722,7 @@ ogm_reader_c::handle_stream_comments() {
   std::string title;
 
   bool charset_warning_printed = false;
-  charset_converter_cptr cch   = charset_converter_c::init(ti.chapter_charset);
+  charset_converter_cptr cch   = charset_converter_c::init(m_ti.m_chapter_charset);
   int i;
 
   for (i = 0; i < sdemuxers.size(); i++) {
@@ -800,29 +795,29 @@ ogm_reader_c::handle_stream_comments() {
     }
 
     bool chapters_set = false;
-    if (!chapter_strings.empty() && !ti.no_chapters) {
+    if (!chapter_strings.empty() && !m_ti.m_no_chapters) {
       try {
         counted_ptr<mm_mem_io_c> out(new mm_mem_io_c(NULL, 0, 1000));
 
         out->write_bom("UTF-8");
         for (j = 0; j < chapter_strings.size(); j++)
           out->puts(cch->utf8(chapter_strings[j]) + std::string("\n"));
-        out->set_file_name(ti.fname);
+        out->set_file_name(m_ti.m_fname);
 
         counted_ptr<mm_text_io_c> text_out(new mm_text_io_c(out.get_object(), false));
 
-        chapters     = parse_chapters(text_out.get_object(), 0, -1, 0, ti.chapter_language);
+        m_chapters   = parse_chapters(text_out.get_object(), 0, -1, 0, m_ti.m_chapter_language);
         chapters_set = true;
 
-        align_chapter_edition_uids(chapters);
+        align_chapter_edition_uids(m_chapters);
       } catch (...) {
       }
     }
 
     if (    (segment_title_set || chapters_set)
          && !charset_warning_printed
-         && (ti.chapter_charset.empty())) {
-      mxwarn_fn(ti.fname,
+         && (m_ti.m_chapter_charset.empty())) {
+      mxwarn_fn(m_ti.m_fname,
                 Y("This Ogg/OGM file contains chapter or title information. Unfortunately the charset used to store this information in "
                   "the file cannot be identified unambiguously. The program assumes that your system's current charset is appropriate. This can "
                   "be overridden with the '--chapter-charset <charset>' switch.\n"));
@@ -836,7 +831,7 @@ ogm_reader_c::add_available_track_ids() {
   int i;
 
   for (i = 0; i < sdemuxers.size(); i++)
-    available_track_ids.push_back(i);
+    add_available_track_id(i);
 }
 
 // -----------------------------------------------------------
@@ -898,7 +893,7 @@ ogm_demuxer_c::process_page(int64_t granulepos) {
     get_duration_and_len(op, duration, duration_len);
 
     memory_c *mem = new memory_c(&op.packet[duration_len + 1], op.bytes - 1 - duration_len, false);
-    reader->reader_packetizers[ptzr]->process(new packet_t(mem));
+    reader->m_reader_packetizers[ptzr]->process(new packet_t(mem));
     units_processed += op.bytes - 1;
   }
 }
@@ -916,7 +911,7 @@ ogm_demuxer_c::process_header_page() {
         continue;
       }
 
-      mxwarn_tid(reader->ti.fname, track_id,
+      mxwarn_tid(reader->m_ti.m_fname, track_id,
                  Y("Missing header/comment packets for stream. This file is broken but should be muxed correctly. "
                    "If not please contact the author Moritz Bunkus <moritz@bunkus.org>.\n"));
       headers_read = true;
@@ -964,13 +959,13 @@ ogm_a_aac_demuxer_c::create_packetizer(track_info_c &ti) {
 
   mxverb(2,
          boost::format("ogm_reader: %1%/%2%: profile %3%, channels %4%, sample_rate %5%, sbr %6%, output_sample_rate %7%\n")
-         % ti.id % ti.fname % profile % channels % sample_rate % sbr % output_sample_rate);
+         % ti.m_id % ti.m_fname % profile % channels % sample_rate % sbr % output_sample_rate);
 
   generic_packetizer_c *ptzr_obj = new aac_packetizer_c(reader, ti, AAC_ID_MPEG4, profile, sample_rate, channels, false, true);
   if (sbr)
     ptzr_obj->set_audio_output_sampling_freq(output_sample_rate);
 
-  mxinfo_tid(ti.fname, ti.id,  Y("Using the AAC output module.\n"));
+  mxinfo_tid(ti.m_fname, ti.m_id,  Y("Using the AAC output module.\n"));
 
   return ptzr_obj;
 }
@@ -988,7 +983,7 @@ ogm_a_ac3_demuxer_c::create_packetizer(track_info_c &ti) {
   stream_header        *sth      = (stream_header *)(packet_data[0]->get_buffer() + 1);
   generic_packetizer_c *ptzr_obj = new ac3_packetizer_c(reader, ti, get_uint64_le(&sth->samples_per_unit), get_uint16_le(&sth->sh.audio.channels), 0);
 
-  mxinfo_tid(ti.fname, ti.id, Y("Using the AC3 output module.\n"));
+  mxinfo_tid(ti.m_fname, ti.m_id, Y("Using the AC3 output module.\n"));
 
   return ptzr_obj;
 }
@@ -1006,7 +1001,7 @@ ogm_a_mp3_demuxer_c::create_packetizer(track_info_c &ti) {
   stream_header        *sth      = (stream_header *)(packet_data[0]->get_buffer() + 1);
   generic_packetizer_c *ptzr_obj = new mp3_packetizer_c(reader, ti, get_uint64_le(&sth->samples_per_unit), get_uint16_le(&sth->sh.audio.channels), true);
 
-  mxinfo_tid(ti.fname, ti.id, Y("Using the MPEG audio output module.\n"));
+  mxinfo_tid(ti.m_fname, ti.m_id, Y("Using the MPEG audio output module.\n"));
 
   return ptzr_obj;
 }
@@ -1025,7 +1020,7 @@ ogm_a_pcm_demuxer_c::create_packetizer(track_info_c &ti) {
   generic_packetizer_c *ptzr_obj = new pcm_packetizer_c(reader, ti, get_uint64_le(&sth->samples_per_unit), get_uint16_le(&sth->sh.audio.channels),
                                                         get_uint16_le(&sth->bits_per_sample));
 
-  mxinfo_tid(ti.fname, ti.id, Y("Using the PCM output module.\n"));
+  mxinfo_tid(ti.m_fname, ti.m_id, Y("Using the PCM output module.\n"));
 
   return ptzr_obj;
 }
@@ -1046,7 +1041,7 @@ ogm_a_vorbis_demuxer_c::create_packetizer(track_info_c &ti) {
                                                            packet_data[1]->get_buffer(), packet_data[1]->get_size(),
                                                            packet_data[2]->get_buffer(), packet_data[2]->get_size());
 
-  mxinfo_tid(ti.fname, ti.id, Y("Using the Vorbis output module.\n"));
+  mxinfo_tid(ti.m_fname, ti.m_id, Y("Using the Vorbis output module.\n"));
 
   return ptzr_obj;
 }
@@ -1061,7 +1056,7 @@ ogm_a_vorbis_demuxer_c::process_page(int64_t granulepos) {
     if (((*op.packet & 3) == PACKET_TYPE_HEADER) || ((*op.packet & 3) == PACKET_TYPE_COMMENT))
       continue;
 
-    reader->reader_packetizers[ptzr]->process(new packet_t(new memory_c(op.packet, op.bytes, false)));
+    reader->m_reader_packetizers[ptzr]->process(new packet_t(new memory_c(op.packet, op.bytes, false)));
   }
 }
 
@@ -1077,7 +1072,7 @@ generic_packetizer_c *
 ogm_s_text_demuxer_c::create_packetizer(track_info_c &ti) {
   generic_packetizer_c *ptzr_obj = new textsubs_packetizer_c(reader, ti, MKV_S_TEXTUTF8, NULL, 0, true, false);
 
-  mxinfo_tid(ti.fname, ti.id, Y("Using the text subtitle output module.\n"));
+  mxinfo_tid(ti.m_fname, ti.m_id, Y("Using the text subtitle output module.\n"));
 
   return ptzr_obj;
 }
@@ -1100,7 +1095,7 @@ ogm_s_text_demuxer_c::process_page(int64_t granulepos) {
 
     if (((op.bytes - 1 - duration_len) > 2) || ((op.packet[duration_len + 1] != ' ') && (op.packet[duration_len + 1] != 0) && !iscr(op.packet[duration_len + 1]))) {
       memory_c *mem = new memory_c(&op.packet[duration_len + 1], op.bytes - 1 - duration_len, false);
-      reader->reader_packetizers[ptzr]->process(new packet_t(mem, granulepos * 1000000, (int64_t)duration * 1000000));
+      reader->m_reader_packetizers[ptzr]->process(new packet_t(mem, granulepos * 1000000, (int64_t)duration * 1000000));
     }
   }
 }
@@ -1121,8 +1116,8 @@ ogm_v_avc_demuxer_c::create_packetizer(track_info_c &ti) {
   try {
     stream_header *sth = (stream_header *)&packet_data[0]->get_buffer()[1];
 
-    ti.private_data    = NULL;
-    ti.private_size    = 0;
+    ti.m_private_data  = NULL;
+    ti.m_private_size  = 0;
     memory_cptr avcc   = extract_avcc();
 
     vptzr              = new mpeg4_p10_es_video_packetizer_c(reader, ti, avcc, get_uint32_le(&sth->sh.video.width), get_uint32_le(&sth->sh.video.height));
@@ -1130,10 +1125,10 @@ ogm_v_avc_demuxer_c::create_packetizer(track_info_c &ti) {
     vptzr->enable_timecode_generation(false);
     vptzr->set_track_default_duration(default_duration);
 
-    mxinfo_tid(ti.fname, ti.id, Y("Using the MPEG-4 part 10 ES video output module.\n"));
+    mxinfo_tid(ti.m_fname, ti.m_id, Y("Using the MPEG-4 part 10 ES video output module.\n"));
 
   } catch (...) {
-    mxerror_tid(ti.fname, ti.id, Y("Could not extract the decoder specific config data (AVCC) from this AVC/h.264 track.\n"));
+    mxerror_tid(ti.m_fname, ti.m_id, Y("Could not extract the decoder specific config data (AVCC) from this AVC/h.264 track.\n"));
   }
 
   return vptzr;
@@ -1144,10 +1139,10 @@ ogm_v_avc_demuxer_c::extract_avcc() {
   avc_es_parser_c parser;
 
   parser.ignore_nalu_size_length_errors();
-  if (map_has_key(reader->ti.nalu_size_lengths, track_id))
-    parser.set_nalu_size_length(reader->ti.nalu_size_lengths[track_id]);
-  else if (map_has_key(reader->ti.nalu_size_lengths, -1))
-    parser.set_nalu_size_length(reader->ti.nalu_size_lengths[-1]);
+  if (map_has_key(reader->m_ti.m_nalu_size_lengths, track_id))
+    parser.set_nalu_size_length(reader->m_ti.m_nalu_size_lengths[track_id]);
+  else if (map_has_key(reader->m_ti.m_nalu_size_lengths, -1))
+    parser.set_nalu_size_length(reader->m_ti.m_nalu_size_lengths[-1]);
 
   unsigned char *private_data = packet_data[0]->get_buffer() + 1 + sizeof(stream_header);
   int private_size            = packet_data[0]->get_size()   - 1 - sizeof(stream_header);
@@ -1223,26 +1218,26 @@ ogm_v_mscomp_demuxer_c::create_packetizer(track_info_c &ti) {
   put_uint32_le(&bih.bi_size_image, get_uint32_le(&bih.bi_width) * get_uint32_le(&bih.bi_height) * 3);
   memcpy(&bih.bi_compression, sth->subtype, 4);
 
-  ti.private_data  = (unsigned char *)&bih;
-  ti.private_size  = sizeof(alBITMAPINFOHEADER);
+  ti.m_private_data  = (unsigned char *)&bih;
+  ti.m_private_size  = sizeof(alBITMAPINFOHEADER);
 
-  double fps       = (double)10000000.0 / get_uint64_le(&sth->time_unit);
-  int width        = get_uint32_le(&sth->sh.video.width);
-  int height       = get_uint32_le(&sth->sh.video.height);
+  double fps         = (double)10000000.0 / get_uint64_le(&sth->time_unit);
+  int width          = get_uint32_le(&sth->sh.video.width);
+  int height         = get_uint32_le(&sth->sh.video.height);
 
   generic_packetizer_c *ptzr_obj;
   if (mpeg4::p2::is_fourcc(sth->subtype)) {
     ptzr_obj = new mpeg4_p2_video_packetizer_c(reader, ti, fps, width, height, false);
 
-    mxinfo_tid(ti.fname, ti.id, Y("Using the MPEG-4 part 2 video output module.\n"));
+    mxinfo_tid(ti.m_fname, ti.m_id, Y("Using the MPEG-4 part 2 video output module.\n"));
 
   } else {
     ptzr_obj = new video_packetizer_c(reader, ti, NULL, fps, width, height);
 
-    mxinfo_tid(ti.fname, ti.id, Y("Using the video output module.\n"));
+    mxinfo_tid(ti.m_fname, ti.m_id, Y("Using the video output module.\n"));
   }
 
-  ti.private_data = NULL;
+  ti.m_private_data = NULL;
 
   return ptzr_obj;
 }
@@ -1285,7 +1280,7 @@ ogm_v_mscomp_demuxer_c::process_page(int64_t granulepos) {
     int64_t timecode = (last_granulepos + frames_since_granulepos_change) * default_duration;
     ++frames_since_granulepos_change;
 
-    reader->reader_packetizers[ptzr]->process(new packet_t(frame.mem, timecode, frame.duration, frame.flags & PACKET_IS_SYNCPOINT ? VFT_IFRAME : VFT_PFRAMEAUTOMATIC));
+    reader->m_reader_packetizers[ptzr]->process(new packet_t(frame.mem, timecode, frame.duration, frame.flags & PACKET_IS_SYNCPOINT ? VFT_IFRAME : VFT_PFRAMEAUTOMATIC));
 
     units_processed += duration;
   }
@@ -1314,22 +1309,22 @@ ogm_v_theora_demuxer_c::initialize() {
     display_width  = theora.display_width;
     display_height = theora.display_height;
   } catch (error_c &e) {
-    mxerror_tid(reader->ti.fname, track_id, boost::format(Y("The Theora identifaction header could not be parsed (%1%).\n")) % e.get_error());
+    mxerror_tid(reader->m_ti.m_fname, track_id, boost::format(Y("The Theora identifaction header could not be parsed (%1%).\n")) % e.get_error());
   }
 }
 
 generic_packetizer_c *
 ogm_v_theora_demuxer_c::create_packetizer(track_info_c &ti) {
   memory_cptr codecprivate       = lace_memory_xiph(packet_data);
-  ti.private_data                = codecprivate->get_buffer();
-  ti.private_size                = codecprivate->get_size();
+  ti.m_private_data              = codecprivate->get_buffer();
+  ti.m_private_size              = codecprivate->get_size();
 
   double                fps      = (double)theora.frn / (double)theora.frd;
   generic_packetizer_c *ptzr_obj = new theora_video_packetizer_c(reader, ti, fps, theora.fmbw, theora.fmbh);
 
-  mxinfo_tid(ti.fname, ti.id, Y("Using the Theora video output module.\n"));
+  mxinfo_tid(ti.m_fname, ti.m_id, Y("Using the Theora video output module.\n"));
 
-  ti.private_data = NULL;
+  ti.m_private_data = NULL;
 
   return ptzr_obj;
 }
@@ -1354,7 +1349,7 @@ ogm_v_theora_demuxer_c::process_page(int64_t granulepos) {
 
     ++units_processed;
 
-    reader->reader_packetizers[ptzr]->process(new packet_t(new memory_c(op.packet, op.bytes, false), timecode, duration, bref, VFT_NOBFRAME));
+    reader->m_reader_packetizers[ptzr]->process(new packet_t(new memory_c(op.packet, op.bytes, false), timecode, duration, bref, VFT_NOBFRAME));
 
     mxverb(3,
            boost::format("Theora track %1% kfgshift %2% granulepos 0x%|3$08x| %|4$08x|%5%\n")
@@ -1385,21 +1380,21 @@ ogm_s_kate_demuxer_c::initialize() {
     kate_parse_identification_header(mem->get_buffer(), mem->get_size(), kate);
     num_header_packets = kate.nheaders;
   } catch (error_c &e) {
-    mxerror_tid(reader->ti.fname, track_id, boost::format(Y("The Kate identifaction header could not be parsed (%1%).\n")) % e.get_error());
+    mxerror_tid(reader->m_ti.m_fname, track_id, boost::format(Y("The Kate identifaction header could not be parsed (%1%).\n")) % e.get_error());
   }
 }
 
 generic_packetizer_c *
 ogm_s_kate_demuxer_c::create_packetizer(track_info_c &ti) {
   memory_cptr codecprivate       = lace_memory_xiph(packet_data);
-  ti.private_data                = codecprivate->get_buffer();
-  ti.private_size                = codecprivate->get_size();
+  ti.m_private_data              = codecprivate->get_buffer();
+  ti.m_private_size              = codecprivate->get_size();
 
-  generic_packetizer_c *ptzr_obj = new kate_packetizer_c(reader, ti, ti.private_data, ti.private_size);
+  generic_packetizer_c *ptzr_obj = new kate_packetizer_c(reader, ti, ti.m_private_data, ti.m_private_size);
 
-  mxinfo_tid(ti.fname, ti.id, Y("Using the Kate subtitle output module.\n"));
+  mxinfo_tid(ti.m_fname, ti.m_id, Y("Using the Kate subtitle output module.\n"));
 
-  ti.private_data = NULL;
+  ti.m_private_data = NULL;
 
   return ptzr_obj;
 }
@@ -1414,7 +1409,7 @@ ogm_s_kate_demuxer_c::process_page(int64_t granulepos) {
     if ((0 == op.bytes) || (0 != (op.packet[0] & 0x80)))
       continue;
 
-    reader->reader_packetizers[ptzr]->process(new packet_t(new memory_c(op.packet, op.bytes, false)));
+    reader->m_reader_packetizers[ptzr]->process(new packet_t(new memory_c(op.packet, op.bytes, false)));
 
     ++units_processed;
 
