@@ -6,8 +6,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_ogm.h 3578 2007-08-16 16:30:05Z mosu $
-
    class definitions for the OGG media stream reader
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
@@ -16,14 +14,14 @@
 #ifndef __R_OGM_FLAC_H
 #define __R_OGM_FLAC_H
 
-#include "os.h"
+#include "common/common_pch.h"
 
 #if defined(HAVE_FLAC_FORMAT_H)
 
 #include <ogg/ogg.h>
 #include <FLAC/stream_decoder.h>
 
-#include "mm_io.h"
+#include "common/mm_io.h"
 
 class flac_header_extractor_c {
 public:
@@ -38,7 +36,7 @@ public:
   bool done;
 
 public:
-  flac_header_extractor_c(const string &file_name, int64_t _sid);
+  flac_header_extractor_c(const std::string &file_name, int64_t _sid);
   ~flac_header_extractor_c();
   bool extract();
   bool read_page();
@@ -55,7 +53,7 @@ public:
     return "audio";
   };
 
-  virtual string get_codec() {
+  virtual std::string get_codec() {
     return "FLAC";
   };
 
