@@ -6,36 +6,29 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_usf.cpp 3867 2008-08-28 10:04:21Z mosu $
-
    USF subtitle reader
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "os.h"
-
-#include <errno.h>
-#include <expat.h>
-#include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
+#include "common/common_pch.h"
 
 #include <algorithm>
 
-#include "iso639.h"
-#include "matroska.h"
-#include "mm_io.h"
-#include "output_control.h"
-#include "pr_generic.h"
-#include "p_textsubs.h"
-#include "r_usf.h"
+#include "common/iso639.h"
+#include "common/matroska.h"
+#include "common/mm_io.h"
+#include "common/strings/parsing.h"
+#include "common/xml/xml.h"
+#include "input/r_usf.h"
+#include "merge/output_control.h"
+#include "merge/pr_generic.h"
+#include "output/p_textsubs.h"
 
-using namespace std;
 
 class usf_xml_find_root_c: public xml_parser_c {
 public:
-  string m_root_element;
+  std::string m_root_element;
 
 public:
   usf_xml_find_root_c(mm_text_io_c *io):
@@ -75,11 +68,11 @@ usf_reader_c::usf_reader_c(track_info_c &_ti)
   m_strip(false) {
 
   try {
-    m_xml_source = new mm_text_io_c(new mm_file_io_c(ti.fname));
+    m_xml_source = new mm_text_io_c(new mm_file_io_c(m_ti.m_fname));
     int i;
 
     if (!usf_reader_c::probe_file(m_xml_source, 0))
-      throw error_c("usf_reader: Source is not a valid USF file.");
+      throw error_c(Y("usf_reader: Source is not a valid USF file."));
 
     parse_xml_file();
     m_private_data += "</USFSubtitles>";
@@ -99,12 +92,12 @@ usf_reader_c::usf_reader_c(track_info_c &_ti)
   } catch (xml_parser_error_c &error) {
     throw error_c(error.get_error());
 
-  } catch (mm_io_error_c &error) {
-    throw error_c("usf_reader: Could not open the source file.");
+  } catch (mm_io_error_c &) {
+    throw error_c(Y("usf_reader: Could not open the source file."));
   }
 
   if (verbose)
-    mxinfo(FMT_FN "Using the USF subtitle reader.\n", ti.fname.c_str());
+    mxinfo_fn(m_ti.m_fname, Y("Using the USF subtitle reader.\n"));
 }
 
 usf_reader_c::~usf_reader_c() {
@@ -114,7 +107,7 @@ void
 usf_reader_c::start_element_cb(const char *name,
                                const char **atts) {
   int i;
-  string node;
+  std::string node;
 
   m_previous_start = name;
   m_parents.push_back(name);
@@ -132,8 +125,8 @@ usf_reader_c::start_element_cb(const char *name,
         int index = map_to_iso639_2_code(atts[i + 1]);
         if (-1 != index)
           m_default_language = iso639_languages[index].iso639_2_code;
-        else if (!identifying)
-          mxwarn(FMT_FN "The default language code '%s' is not a valid ISO639-2 language code and will be ignored.\n", ti.fname.c_str(), atts[i + 1]);
+        else if (!g_identifying)
+          mxwarn_fn(m_ti.m_fname, boost::format(Y("The default language code '%1%' is not a valid ISO639-2 language code and will be ignored.\n")) % atts[i + 1]);
         break;
       }
   }
@@ -164,8 +157,8 @@ usf_reader_c::start_element_cb(const char *name,
         if (-1 != index)
           m_tracks[m_tracks.size() - 1].m_language =
             iso639_languages[index].iso639_2_code;
-        else if (!identifying)
-          mxwarn(FMT_TID "The language code '%s' is not a valid ISO639-2 language code and will be ignored.\n", ti.fname.c_str(), (int64_t)m_tracks.size(), atts[i + 1]);
+        else if (!g_identifying)
+          mxwarn_tid(m_ti.m_fname, m_tracks.size(), boost::format(Y("The language code '%1%' is not a valid ISO639-2 language code and will be ignored.\n")) % atts[i + 1]);
         break;
       }
 
@@ -203,7 +196,7 @@ usf_reader_c::start_element_cb(const char *name,
 void
 usf_reader_c::end_element_cb(const char *name) {
   int i;
-  string node;
+  std::string node;
 
   // Generate the full path to this node.
   for (i = 0; m_parents.size() > i; ++i) {
@@ -261,9 +254,9 @@ usf_reader_c::create_packetizer(int64_t tid) {
   if (!demuxing_requested('s', tid) || (-1 != track.m_ptzr))
     return;
 
-  ti.language  = track.m_language;
-  track.m_ptzr = add_packetizer(new textsubs_packetizer_c(this, MKV_S_TEXTUSF, m_private_data.c_str(), m_private_data.length(), false, true, ti));
-  mxinfo(FMT_TID "Using the text subtitle output module.\n", ti.fname.c_str(), tid);
+  m_ti.m_language = track.m_language;
+  track.m_ptzr    = add_packetizer(new textsubs_packetizer_c(this, m_ti, MKV_S_TEXTUSF, m_private_data.c_str(), m_private_data.length(), false, true));
+  mxinfo_tid(m_ti.m_fname, tid, Y("Using the text subtitle output module.\n"));
 }
 
 void
@@ -315,7 +308,7 @@ usf_reader_c::get_progress() {
   usf_track_t &track = m_tracks[m_longest_track];
   if (track.m_entries.size() == 0)
     return 0;
-  return 100 - distance(track.m_current_entry, (vector<usf_entry_t>::const_iterator)track.m_entries.end()) * 100 / track.m_entries.size();
+  return 100 - distance(track.m_current_entry, (std::vector<usf_entry_t>::const_iterator)track.m_entries.end()) * 100 / track.m_entries.size();
 }
 
 int64_t
@@ -323,14 +316,14 @@ usf_reader_c::try_to_parse_timecode(const char *s) {
   int64_t timecode;
 
   if (!parse_timecode(s, timecode))
-    throw xml_parser_error_c("Invalid start or stop timecode", m_xml_parser);
+    throw xml_parser_error_c(Y("Invalid start or stop timecode"), m_xml_parser);
 
   return timecode;
 }
 
 void
 usf_reader_c::identify() {
-  vector<string> verbose_info;
+  std::vector<std::string> verbose_info;
   int i;
 
   id_result_container("USF");
@@ -341,7 +334,7 @@ usf_reader_c::identify() {
     verbose_info.clear();
 
     if (!track.m_language.empty())
-      verbose_info.push_back(string("language:") + escape(track.m_language));
+      verbose_info.push_back(std::string("language:") + escape(track.m_language));
 
     id_result_track(i, ID_RESULT_TRACK_SUBTITLES, "USF", verbose_info);
   }
