@@ -15,14 +15,13 @@
 #ifndef __R_VOBBTN_H
 #define __R_VOBBTN_H
 
-#include "os.h"
+#include "common/common_pch.h"
 
 #include <stdio.h>
 
-#include "common.h"
-#include "mm_io.h"
-#include "pr_generic.h"
-#include "p_vobbtn.h"
+#include "common/mm_io.h"
+#include "merge/pr_generic.h"
+#include "output/p_vobbtn.h"
 
 class vobbtn_reader_c: public generic_reader_c {
 private:
