@@ -6,8 +6,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_wav.cpp 3985 2008-10-11 16:00:12Z mosu $
-
    WAV reader module
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
@@ -15,7 +13,7 @@
      modified by Moritz Bunkus.
 */
 
-#include "os.h"
+#include "common/common_pch.h"
 
 #include <algorithm>
 
@@ -28,23 +26,16 @@
 #include <unistd.h>
 #endif
 
-#include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
-#include <errno.h>
+#include "common/ac3.h"
+#include "common/dts.h"
+#include "common/endian.h"
+#include "common/error.h"
+#include "input/r_wav.h"
+#include "output/p_ac3.h"
+#include "output/p_dts.h"
+#include "output/p_pcm.h"
 
-#include "common.h"
-#include "ac3_common.h"
-#include "dts_common.h"
-#include "error.h"
-#include "r_wav.h"
-#include "p_ac3.h"
-#include "p_dts.h"
-#include "p_pcm.h"
-
-extern "C" {
 #include <avilib.h> // for wave_header
-}
 
 #define AC3ACM_READ_SIZE 100000
 
@@ -67,12 +58,12 @@ public:
   };
 
   virtual unsigned char *get_buffer() {
-    return m_buf[m_cur_buf]->get();
+    return m_buf[m_cur_buf]->get_buffer();
   };
 
   virtual void process(int64_t len);
   virtual generic_packetizer_c *create_packetizer();
-  virtual string get_codec() {
+  virtual std::string get_codec() {
     return 16 == m_ac3header.bsid ? "EAC3" : "AC3";
   };
 
@@ -137,12 +128,12 @@ public:
   };
 
   virtual unsigned char *get_buffer() {
-    return m_buf[m_cur_buf]->get();
+    return m_buf[m_cur_buf]->get_buffer();
   };
 
   virtual void process(int64_t len);
   virtual generic_packetizer_c *create_packetizer();
-  virtual string get_codec() {
+  virtual std::string get_codec() {
     return "DTS";
   };
 
@@ -166,12 +157,12 @@ public:
   };
 
   virtual unsigned char *get_buffer() {
-    return m_buffer->get();
+    return m_buffer->get_buffer();
   };
 
   virtual void process(int64_t len);
   virtual generic_packetizer_c *create_packetizer();
-  virtual string get_codec() {
+  virtual std::string get_codec() {
     return "PCM";
   };
 
@@ -198,21 +189,21 @@ wav_ac3acm_demuxer_c::~wav_ac3acm_demuxer_c() {
 bool
 wav_ac3acm_demuxer_c::probe(mm_io_cptr &io) {
   io->save_pos();
-  int len = io->read(m_buf[m_cur_buf]->get(), AC3ACM_READ_SIZE);
+  int len = io->read(m_buf[m_cur_buf]->get_buffer(), AC3ACM_READ_SIZE);
   io->restore_pos();
 
-  int pos = find_consecutive_ac3_headers(m_buf[m_cur_buf]->get(), len, 4);
+  int pos = find_consecutive_ac3_headers(m_buf[m_cur_buf]->get_buffer(), len, 4);
 
   if (-1 == pos) {
     m_swap_bytes = true;
     decode_buffer(len);
-    pos = find_consecutive_ac3_headers(m_buf[m_cur_buf]->get(), len, 4);
+    pos = find_consecutive_ac3_headers(m_buf[m_cur_buf]->get_buffer(), len, 4);
   }
 
   if (-1 == pos)
     return false;
 
-  find_ac3_header(m_buf[m_cur_buf]->get() + pos, len - pos, &m_ac3header, true);
+  find_ac3_header(m_buf[m_cur_buf]->get_buffer() + pos, len - pos, &m_ac3header, true);
 
   return true;
 }
@@ -220,7 +211,7 @@ wav_ac3acm_demuxer_c::probe(mm_io_cptr &io) {
 int
 wav_ac3acm_demuxer_c::decode_buffer(int len) {
   if ((2 < len) && m_swap_bytes) {
-    swab((char *)m_buf[m_cur_buf]->get(), (char *)m_buf[m_cur_buf ^ 1]->get(), len);
+    swab((char *)m_buf[m_cur_buf]->get_buffer(), (char *)m_buf[m_cur_buf ^ 1]->get_buffer(), len);
     m_cur_buf ^= 1;
   }
 
@@ -229,9 +220,9 @@ wav_ac3acm_demuxer_c::decode_buffer(int len) {
 
 generic_packetizer_c *
 wav_ac3acm_demuxer_c::create_packetizer() {
-  m_ptzr = new ac3_packetizer_c(m_reader, m_reader->ti, m_ac3header.sample_rate, m_ac3header.channels, m_ac3header.bsid);
+  m_ptzr = new ac3_packetizer_c(m_reader, m_reader->m_ti, m_ac3header.sample_rate, m_ac3header.channels, m_ac3header.bsid);
 
-  mxinfo_tid(m_reader->ti.fname, 0, Y("Using the AC3 output module.\n"));
+  mxinfo_tid(m_reader->m_ti.m_fname, 0, Y("Using the AC3 output module.\n"));
 
   return m_ptzr;
 }
@@ -242,7 +233,7 @@ wav_ac3acm_demuxer_c::process(int64_t size) {
     return;
 
   decode_buffer(size);
-  m_ptzr->process(new packet_t(new memory_c(m_buf[m_cur_buf]->get(), size, false)));
+  m_ptzr->process(new packet_t(new memory_c(m_buf[m_cur_buf]->get_buffer(), size, false)));
 }
 
 // ----------------------------------------------------------
@@ -258,7 +249,7 @@ wav_ac3wav_demuxer_c::~wav_ac3wav_demuxer_c() {
 bool
 wav_ac3wav_demuxer_c::probe(mm_io_cptr &io) {
   io->save_pos();
-  int len = io->read(m_buf[m_cur_buf]->get(), AC3WAV_BLOCK_SIZE);
+  int len = io->read(m_buf[m_cur_buf]->get_buffer(), AC3WAV_BLOCK_SIZE);
   io->restore_pos();
 
   if (decode_buffer(len) > 0)
@@ -274,12 +265,12 @@ wav_ac3wav_demuxer_c::decode_buffer(int len) {
     return -1;
 
   if (m_swap_bytes) {
-    memcpy(      m_buf[m_cur_buf ^ 1]->get(),         m_buf[m_cur_buf]->get(),         8);
-    swab((char *)m_buf[m_cur_buf]->get() + 8, (char *)m_buf[m_cur_buf ^ 1]->get() + 8, len - 8);
+    memcpy(      m_buf[m_cur_buf ^ 1]->get_buffer(),         m_buf[m_cur_buf]->get_buffer(),         8);
+    swab((char *)m_buf[m_cur_buf]->get_buffer() + 8, (char *)m_buf[m_cur_buf ^ 1]->get_buffer() + 8, len - 8);
     m_cur_buf ^= 1;
   }
 
-  unsigned char *base = m_buf[m_cur_buf]->get();
+  unsigned char *base = m_buf[m_cur_buf]->get_buffer();
 
   if ((get_uint16_le(&base[0]) != AC3WAV_SYNC_WORD1) || (get_uint16_le(&base[2]) != AC3WAV_SYNC_WORD2) || (0x01 != base[4]))
     return -1;
@@ -301,7 +292,7 @@ wav_ac3wav_demuxer_c::process(int64_t size) {
 
   long dec_len = decode_buffer(size);
   if (0 < dec_len)
-    m_ptzr->process(new packet_t(new memory_c(m_buf[m_cur_buf]->get() + 8, dec_len, false)));
+    m_ptzr->process(new packet_t(new memory_c(m_buf[m_cur_buf]->get_buffer() + 8, dec_len, false)));
 }
 
 // ----------------------------------------------------------
@@ -323,13 +314,13 @@ wav_dts_demuxer_c::~wav_dts_demuxer_c() {
 bool
 wav_dts_demuxer_c::probe(mm_io_cptr &io) {
   io->save_pos();
-  int len = io->read(m_buf[m_cur_buf]->get(), DTS_READ_SIZE);
+  int len = io->read(m_buf[m_cur_buf]->get_buffer(), DTS_READ_SIZE);
   io->restore_pos();
 
-  if (detect_dts(m_buf[m_cur_buf]->get(), len, m_pack_14_16, m_swap_bytes)) {
+  if (detect_dts(m_buf[m_cur_buf]->get_buffer(), len, m_pack_14_16, m_swap_bytes)) {
     len = decode_buffer(len);
-    if (find_dts_header(m_buf[m_cur_buf]->get(), len, &m_dtsheader) >= 0) {
-      mxverb(3, boost::format(Y("DTSinWAV: 14->16 %1% swap %2%\n")) % m_pack_14_16 % m_swap_bytes);
+    if (find_dts_header(m_buf[m_cur_buf]->get_buffer(), len, &m_dtsheader) >= 0) {
+      mxverb(3, boost::format("DTSinWAV: 14->16 %1% swap %2%\n") % m_pack_14_16 % m_swap_bytes);
       return true;
     }
   }
@@ -340,12 +331,12 @@ wav_dts_demuxer_c::probe(mm_io_cptr &io) {
 int
 wav_dts_demuxer_c::decode_buffer(int len) {
   if (m_swap_bytes) {
-    swab((char *)m_buf[m_cur_buf]->get(), (char *)m_buf[m_cur_buf ^ 1]->get(), len);
+    swab((char *)m_buf[m_cur_buf]->get_buffer(), (char *)m_buf[m_cur_buf ^ 1]->get_buffer(), len);
     m_cur_buf ^= 1;
   }
 
   if (m_pack_14_16) {
-    dts_14_to_dts_16((unsigned short *)m_buf[m_cur_buf]->get(), len / 2, (unsigned short *)m_buf[m_cur_buf ^ 1]->get());
+    dts_14_to_dts_16((unsigned short *)m_buf[m_cur_buf]->get_buffer(), len / 2, (unsigned short *)m_buf[m_cur_buf ^ 1]->get_buffer());
     m_cur_buf ^= 1;
     len        = len * 7 / 8;
   }
@@ -355,12 +346,12 @@ wav_dts_demuxer_c::decode_buffer(int len) {
 
 generic_packetizer_c *
 wav_dts_demuxer_c::create_packetizer() {
-  m_ptzr = new dts_packetizer_c(m_reader, m_reader->ti, m_dtsheader);
+  m_ptzr = new dts_packetizer_c(m_reader, m_reader->m_ti, m_dtsheader);
 
   // .wav with DTS are always filled up with other stuff to match the bitrate.
   ((dts_packetizer_c *)m_ptzr)->set_skipping_is_normal(true);
 
-  mxinfo_tid(m_reader->ti.fname, 0, Y("Using the DTS output module.\n"));
+  mxinfo_tid(m_reader->m_ti.m_fname, 0, Y("Using the DTS output module.\n"));
 
   if (1 < verbose)
     print_dts_header(&m_dtsheader);
@@ -374,7 +365,7 @@ wav_dts_demuxer_c::process(int64_t size) {
     return;
 
   long dec_len = decode_buffer(size);
-  m_ptzr->process(new packet_t(new memory_c(m_buf[m_cur_buf]->get(), dec_len, false)));
+  m_ptzr->process(new packet_t(new memory_c(m_buf[m_cur_buf]->get_buffer(), dec_len, false)));
 }
 
 // ----------------------------------------------------------
@@ -395,13 +386,13 @@ wav_pcm_demuxer_c::~wav_pcm_demuxer_c() {
 
 generic_packetizer_c *
 wav_pcm_demuxer_c::create_packetizer() {
-  m_ptzr = new pcm_packetizer_c(m_reader, m_reader->ti,
+  m_ptzr = new pcm_packetizer_c(m_reader, m_reader->m_ti,
                                 get_uint32_le(&m_wheader->common.dwSamplesPerSec),
                                 get_uint16_le(&m_wheader->common.wChannels),
                                 get_uint16_le(&m_wheader->common.wBitsPerSample),
                                 false, ieee_float);
 
-  mxinfo_tid(m_reader->ti.fname, 0, Y("Using the PCM output module.\n"));
+  mxinfo_tid(m_reader->m_ti.m_fname, 0, Y("Using the PCM output module.\n"));
 
   return m_ptzr;
 }
@@ -411,7 +402,7 @@ wav_pcm_demuxer_c::process(int64_t len) {
   if (0 >= len)
     return;
 
-  m_ptzr->process(new packet_t(new memory_c(m_buffer->get(), len, false)));
+  m_ptzr->process(new packet_t(new memory_c(m_buffer->get_buffer(), len, false)));
 }
 
 // ----------------------------------------------------------
@@ -450,7 +441,7 @@ wav_reader_c::wav_reader_c(track_info_c &ti_)
   int64_t size;
 
   try {
-    m_io = mm_io_cptr(new mm_file_io_c(ti.fname));
+    m_io = mm_io_cptr(new mm_file_io_c(m_ti.m_fname));
     m_io->setFilePointer(0, seek_end);
     size = m_io->getFilePointer();
     m_io->setFilePointer(0, seek_beginning);
@@ -458,7 +449,7 @@ wav_reader_c::wav_reader_c(track_info_c &ti_)
     throw error_c(Y("wav_reader: Could not open the source file."));
   }
 
-  if (!wav_reader_c::probe_file(m_io.get(), size))
+  if (!wav_reader_c::probe_file(m_io.get_object(), size))
     throw error_c(Y("wav_reader: Source is not a valid WAVE file."));
 
   parse_file();
@@ -489,14 +480,43 @@ wav_reader_c::parse_file() {
   if ((m_cur_data_chunk_idx = find_chunk("data", 0, false)) == -1)
     throw error_c(Y("wav_reader: No data chunk was found."));
 
+  if (debugging_requested("wav_reader") || debugging_requested("wav_reader_headers"))
+    dump_headers();
+
   m_io->setFilePointer(m_chunks[m_cur_data_chunk_idx].pos + sizeof(struct chunk_struct), seek_beginning);
 
   m_remaining_bytes_in_current_data_chunk = m_chunks[m_cur_data_chunk_idx].len;
 }
 
+void
+wav_reader_c::dump_headers() {
+  mxinfo(boost::format("File '%1%' wave_header dump\n"
+                       "  riff:\n"
+                       "    id:      %2%%3%%4%%5%\n"
+                       "    len:     %6%\n"
+                       "    wave_id: %7%%8%%9%%10%\n"
+                       "  common:\n"
+                       "    wFormatTag:       %|11$04x|\n"
+                       "    wChannels:        %12%\n"
+                       "    dwSamplesPerSec:  %13%\n"
+                       "    dwAvgBytesPerSec: %14%\n"
+                       "    wBlockAlign:      %15%\n"
+                       "    wBitsPerSample:   %16%\n")
+         % m_ti.m_fname
+         % char(m_wheader.riff.id[0]) % char(m_wheader.riff.id[1]) % char(m_wheader.riff.id[2]) % char(m_wheader.riff.id[3])
+         % get_uint32_le(&m_wheader.riff.len)
+         % char(m_wheader.riff.wave_id[0]) % char(m_wheader.riff.wave_id[1]) % char(m_wheader.riff.wave_id[2]) % char(m_wheader.riff.wave_id[3])
+         % get_uint16_le(&m_wheader.common.wFormatTag)
+         % get_uint16_le(&m_wheader.common.wChannels)
+         % get_uint32_le(&m_wheader.common.dwSamplesPerSec)
+         % get_uint32_le(&m_wheader.common.dwAvgBytesPerSec)
+         % get_uint16_le(&m_wheader.common.wBlockAlign)
+         % get_uint16_le(&m_wheader.common.wBitsPerSample));
+}
+
 void
 wav_reader_c::create_demuxer() {
-  ti.id = 0;                    // ID for this track.
+  m_ti.m_id = 0;                    // ID for this track.
 
   uint16_t format_tag = get_uint16_le(&m_wheader.common.wFormatTag);
   bool ieee_float     = 0x0003 == format_tag;
@@ -507,23 +527,23 @@ wav_reader_c::create_demuxer() {
       m_demuxer.clear();
   }
 
-  if (!m_demuxer.get()) {
+  if (!m_demuxer.is_set()) {
     m_demuxer = wav_demuxer_cptr(new wav_dts_demuxer_c(this, &m_wheader));
     if (!m_demuxer->probe(m_io))
       m_demuxer.clear();
   }
 
-  if (!m_demuxer.get()) {
+  if (!m_demuxer.is_set()) {
     m_demuxer = wav_demuxer_cptr(new wav_ac3wav_demuxer_c(this, &m_wheader));
     if (!m_demuxer->probe(m_io))
       m_demuxer.clear();
   }
 
-  if (!m_demuxer.get())
+  if (!m_demuxer.is_set())
     m_demuxer = wav_demuxer_cptr(new wav_pcm_demuxer_c(this, &m_wheader, ieee_float));
 
   if (verbose)
-    mxinfo_fn(ti.fname, Y("Using the WAV demultiplexer.\n"));
+    mxinfo_fn(m_ti.m_fname, Y("Using the WAV demultiplexer.\n"));
 }
 
 void
@@ -572,6 +592,7 @@ wav_reader_c::read(generic_packetizer_c *,
 void
 wav_reader_c::scan_chunks() {
   wav_chunk_t new_chunk;
+  bool debug_chunks = debugging_requested("wav_reader") || debugging_requested("wav_reader_chunks");
 
   try {
     int64_t file_size = m_io->get_size();
@@ -584,9 +605,9 @@ wav_reader_c::scan_chunks() {
 
       new_chunk.len = m_io->read_uint32_le();
 
-      mxverb(2,
-             boost::format(Y("wav_reader_c::scan_chunks() new chunk at %1% type %2% length %3%\n"))
-             % new_chunk.pos % get_displayable_string(new_chunk.id, 4) % new_chunk.len);
+      if (debug_chunks)
+        mxinfo(boost::format("wav_reader_c::scan_chunks() new chunk at %1% type %2% length %3%\n")
+               % new_chunk.pos % get_displayable_string(new_chunk.id, 4) % new_chunk.len);
 
       if (!strncasecmp(new_chunk.id, "data", 4))
         m_bytes_in_data_chunks += new_chunk.len;
@@ -598,9 +619,9 @@ wav_reader_c::scan_chunks() {
         m_bytes_in_data_chunks      += this_chunk_len;
         previous_chunk.len           = this_chunk_len;
 
-        mxverb(2,
-               boost::format(Y("wav_reader_c::scan_chunks() hugh data chunk with wrong length at %1%; re-calculated from file size; new length %2%\n"))
-               % previous_chunk.pos % previous_chunk.len);
+        if (debug_chunks)
+          mxinfo(boost::format("wav_reader_c::scan_chunks() hugh data chunk with wrong length at %1%; re-calculated from file size; new length %2%\n")
+                 % previous_chunk.pos % previous_chunk.len);
 
         break;
       }
