@@ -11,12 +11,10 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "common/os.h"
+#include "common/common_pch.h"
 
-#include "common/common.h"
 #include "common/endian.h"
 #include "common/extern_data.h"
-#include "common/locale.h"
 #include "common/mm_io.h"
 #include "common/strings/formatting.h"
 #include "common/strings/parsing.h"
@@ -44,8 +42,11 @@ bool
 srt_parser_c::probe(mm_text_io_c *io) {
   try {
     io->setFilePointer(0, seek_beginning);
-    std::string s = io->getline();
-    strip(s);
+    std::string s;
+    do {
+      s = io->getline();
+      strip(s);
+    } while (s.empty());
 
     int64_t dummy;
     if (!parse_int(s, dummy))
