@@ -15,7 +15,7 @@
 #ifndef __OUTPUT_CONTROL_H
 #define __OUTPUT_CONTROL_H
 
-#include "common/os.h"
+#include "common/common_pch.h"
 
 #include <deque>
 
@@ -200,7 +200,6 @@ extern append_mode_e g_append_mode;
 void get_file_type(filelist_t &file);
 void create_readers();
 
-void setup();
 void cleanup();
 void main_loop();
 
@@ -208,10 +207,14 @@ void add_packetizer_globally(generic_packetizer_c *packetizer);
 void add_tags(KaxTag *tags);
 
 void create_next_output_file();
-void finish_file(bool last_file = false);
+int64_t finish_file(bool last_file = false);
 void rerender_track_headers();
 std::string create_output_name();
 
 int64_t add_attachment(attachment_t attachment);
 
+#if defined(SYS_UNIX) || defined(COMP_CYGWIN) || defined(SYS_APPLE)
+void sighandler(int signum);
+#endif
+
 #endif // __OUTPUT_CONTROL_H
