@@ -18,7 +18,7 @@
 
 #include "common/chapters/chapters.h"
 #include "common/command_line.h"
-#include "common/common.h"
+#include "common/common_pch.h"
 #include "common/extern_data.h"
 #include "common/extern_data.h"
 #include "common/fs_sys_helpers.h"
