@@ -14,7 +14,12 @@
 #ifndef __MMG_DIALOG_H
 #define __MMG_DIALOG_H
 
-#include "wx/html/helpctrl.h"
+#include "common/os.h"
+
+#include <wx/html/helpctrl.h>
+#include <wx/log.h>
+
+#include "mmg/mmg.h"
 
 #define ID_TC_OUTPUT                      10000
 #define ID_B_BROWSEOUTPUT                 10001
@@ -31,6 +36,7 @@
 #define ID_M_FILE_SETOUTPUT               60003
 #define ID_M_FILE_EXIT                    60004
 #define ID_M_FILE_OPTIONS                 60005
+#define ID_M_FILE_HEADEREDITOR            60006
 #define ID_M_FILE_LOADSEPARATOR           60090
 #define ID_M_FILE_LOADLAST1               60091
 #define ID_M_FILE_LOADLAST2               60092
@@ -52,7 +58,6 @@
 #define ID_M_CHAPTERS_SAVEAS              60203
 #define ID_M_CHAPTERS_SAVETOKAX           60204
 #define ID_M_CHAPTERS_VERIFY              60205
-#define ID_M_CHAPTERS_SETDEFAULTS         60210
 #define ID_M_CHAPTERS_LOADSEPARATOR       60290
 #define ID_M_CHAPTERS_LOADLAST1           60291
 #define ID_M_CHAPTERS_LOADLAST2           60292
@@ -67,12 +72,20 @@
 #define ID_M_HELP_ABOUT                   65000
 #define ID_M_HELP_HELP                    65001
 
+#define HELP_ID_CONTENTS                      1
+#define HELP_ID_INTRODUCTION              10000
+#define HELP_ID_SETUP                     20000
+#define HELP_ID_MUXING                    30000
+#define HELP_ID_CHAPTER_EDITOR            40000
+#define HELP_ID_HEADER_EDITOR             50000
+
 /* class tab_advanced; */
 class tab_attachments;
 class tab_chapters;
 class tab_global;
 class tab_input;
 class job_dialog;
+class header_editor_frame_c;
 
 class mmg_dialog: public wxFrame {
   DECLARE_CLASS(mmg_dialog);
@@ -88,6 +101,7 @@ public:
   wxTimer status_bar_timer;
 
   wxStatusBar *status_bar;
+  wxStaticBox *sb_output_filename;
 
   wxNotebook *notebook;
   wxMenu *file_menu, *chapter_menu;
@@ -111,6 +125,12 @@ public:
 
   mmg_options_t options;
 
+  std::vector<header_editor_frame_c *> header_editor_frames;
+
+#if defined(SYS_WINDOWS)
+  bool m_taskbar_msg_received;
+#endif
+
 public:
   mmg_dialog();
   virtual ~mmg_dialog();
@@ -170,15 +190,21 @@ public:
 
   void on_close(wxCloseEvent &evt);
 
+  void on_run_header_editor(wxCommandEvent &evt);
+  void header_editor_frame_closed(header_editor_frame_c *frame);
+
+  void translate_ui();
+
   void load_job_queue();
   void save_job_queue();
 
   void set_on_top(bool on_top);
   void restore_on_top();
 
-  void muxing_has_finished();
+  void muxing_has_finished(int exit_code);
 
   bool check_before_overwriting();
+  bool is_output_file_name_valid();
 
   void load_preferences();
   void save_preferences();
@@ -186,6 +212,17 @@ public:
   void remember_previous_output_directory();
 
   void query_mkvmerge_capabilities();
+
+  void display_help(int id);
+
+protected:
+#if defined(SYS_WINDOWS)
+  virtual WXLRESULT MSWWindowProc(WXUINT msg, WXWPARAM wParam, WXLPARAM lParam);
+  void RegisterWindowMessages();
+#endif
+
+  void set_menu_item_strings(int id, const wxString &title, const wxString &help_text = wxEmptyString);
+  void create_menus();
 };
 
 extern mmg_dialog *mdlg;
