@@ -24,7 +24,7 @@
 #include <ebml/EbmlStream.h>
 
 #include "common/chapters/chapters.h"
-#include "common/common.h"
+#include "common/common_pch.h"
 #include "common/ebml.h"
 #include "common/error.h"
 #include "common/extern_data.h"
