@@ -24,7 +24,7 @@
 #include <wx/config.h>
 #include <wx/regex.h>
 
-#include "common/common.h"
+#include "common/common_pch.h"
 #include "common/strings/editing.h"
 #include "common/strings/parsing.h"
 #include "mmg/mmg.h"
@@ -66,6 +66,8 @@ tab_global::tab_global(wxWindow *parent):
   cob_split_by_size->Append(wxT("703M"));
   cob_split_by_size->Append(wxT("800M"));
   cob_split_by_size->Append(wxT("1000M"));
+  cob_split_by_size->Append(wxT("4483M"));
+  cob_split_by_size->Append(wxT("8142M"));
   cob_split_by_size->Enable(false);
   siz_line2->Add(cob_split_by_size, 1, wxALIGN_CENTER_VERTICAL | wxRIGHT | wxGROW, 10);
 
