@@ -38,6 +38,8 @@ class MPEGFrame {
 public:
   binary *data;
   uint32_t size;
+  binary *seqHdrData;
+  uint32_t seqHdrDataSize;
   MediaTime duration;
   char frameType;
   MediaTime timecode;
@@ -59,16 +61,18 @@ private:
   std::queue<MPEGFrame*> buffers; //Holds stamped buffers until they are requested.
   MediaTime position;
   //Added to allow reading the header's raw data, contains first found seq hdr.
-  MPEGChunk* seqHdrChunk;
+  MPEGChunk* seqHdrChunk, *gopChunk;
   MPEG2SequenceHeader m_seqHdr; //current sequence header
-  MediaTime currentStampingTime;
   MediaTime firstRef;
   bool needInit;
   bool m_eos;
   bool notReachedFirstGOP;
-  MediaTime nextSkip;
-  MediaTime nextSkipDuration;
+  bool keepSeqHdrsInBitstream;
   MediaTime secondRef;
+  MediaTime frameNum;
+  MediaTime gopPts;
+  MediaTime highestPts;
+  bool usePictureFrames;
   uint8_t mpegVersion;
   MPEG2ParserState_e parserState;
   MPEGVideoBuffer * mpgBuf;
@@ -76,10 +80,9 @@ private:
   int32_t InitParser();
   void DumpQueues();
   int32_t FillQueues();
-  MediaTime CountBFrames();
   void ShoveRef(MediaTime ref);
   MediaTime GetFrameDuration(MPEG2PictureHeader picHdr);
-  int32_t QueueFrame(MPEGChunk* seqHdr, MPEGChunk* chunk, MediaTime timecode, MPEG2PictureHeader picHdr);
+  int32_t QueueFrame(MPEGChunk* chunk, MediaTime timecode, MPEG2PictureHeader picHdr);
 public:
   M2VParser();
   virtual ~M2VParser();
@@ -117,6 +120,10 @@ public:
   //Sets "end of stream" status on the buffer, forces timestamping of frames waiting.
   //Do not call this without good reason.
   void SetEOS();
+
+  void SeparateSequenceHeaders() {
+    keepSeqHdrsInBitstream = false;
+  }
 };
 
 
