@@ -114,7 +114,6 @@ int32_t MPEGVideoBuffer::Feed(binary* data, uint32_t numBytes){
 
 void ParseSequenceHeader(MPEGChunk* chunk, MPEG2SequenceHeader & hdr){
   binary* pos = chunk->GetPointer();
-  uint8_t haveSeqExt = 0;
   //Parse out the resolution info, horizontal first
   pos+=4; //Skip the start code
   hdr.width = (((unsigned int)pos[0]) << 4) | (((unsigned int) pos[1])>>4);  //xx x0 00
@@ -130,9 +129,6 @@ void ParseSequenceHeader(MPEGChunk* chunk, MPEG2SequenceHeader & hdr){
       break;
     case 0x30:
       hdr.aspectRatio = (16.0f / 9.0f);
-      //playuing with AR
-      /*pos[0] &=0x0F;
-        pos[0] |= 0x20;*/
       break;
     case 0x40:
       hdr.aspectRatio = 2.21f;
@@ -142,56 +138,46 @@ void ParseSequenceHeader(MPEGChunk* chunk, MPEG2SequenceHeader & hdr){
   }
   switch(pos[0] & 0x0F){
     case 0x01:
-      hdr.frameRate = 24000.0f/1001.0f;//23.976
+      hdr.frameOrFieldRate = 24000.0f/1001.0f;//23.976
       break;
     case 0x02:
-      hdr.frameRate = 24.0f;//24
+      hdr.frameOrFieldRate = 24.0f;//24
       break;
     case 0x03:
-      hdr.frameRate = 25.0f;//25
+      hdr.frameOrFieldRate = 25.0f;//25
       break;
     case 0x04:
-      hdr.frameRate = 30000.0f/1001.0f;//29.97
-      //Let's play some more ;)
-      /*pos[0] &= 0xF0; //clear the framerate
-        pos[0] |= 0x01;
-        hdr->frameRate = 24000.0f/1001.0f;//23.976*/
+      hdr.frameOrFieldRate = 30000.0f/1001.0f;//29.97
       break;
     case 0x05:
-      hdr.frameRate = 30.0f;//30
+      hdr.frameOrFieldRate = 30.0f;//30
       break;
     case 0x06:
-      hdr.frameRate = 50.0f;//50
+      hdr.frameOrFieldRate = 50.0f;//50
       break;
     case 0x07:
-      hdr.frameRate = 60000.0f / 1001.0f;//59.94
+      hdr.frameOrFieldRate = 60000.0f / 1001.0f;//59.94
       break;
     case 0x08:
-      hdr.frameRate = 60.0f;//60
+      hdr.frameOrFieldRate = 60.0f;//60
       break;
     default:
-      hdr.frameRate = 0.0f;
+      hdr.frameOrFieldRate = 0.0f;
   }
 
   //Seek to picturecoding extension
-  while(pos < (chunk->GetPointer() + chunk->GetSize() - 4)){
+  hdr.progressiveSequence = 0;
+  while(pos < (chunk->GetPointer() + chunk->GetSize() - 6)){
     if((pos[0] == 0x00) && (pos[1] == 0x00) && (pos[2] == 0x01) && (pos[3] == MPEG_VIDEO_EXT_START_CODE)){
-      if((pos[4] & 0xF0) == 0x01){ //Picture coding extension
-        //printf("Found a picture_coding_extension\n");
-        haveSeqExt = 1;
-        pos+=4;
+      if((pos[4] & 0xF0) == 0x10){ // Sequence extension
+        hdr.profileLevelIndication = ((pos[4] & 0x0F) << 4) | ((pos[5] & 0xF0) >> 4);
+        hdr.progressiveSequence = (pos[5] & 0x08) >> 3;
+        pos+=6;
         break;
       }
     }
     pos++;
   }
-
-  if(haveSeqExt){
-    pos++;
-    hdr.progressiveSequence = (pos[0] & 0x80);
-  }else{
-    hdr.progressiveSequence = 0;
-  }
 }
 
 bool ParseGOPHeader(MPEGChunk* chunk, MPEG2GOPHeader & hdr){
