@@ -14,11 +14,10 @@
 #ifndef __P_VC1_H
 #define __P_VC1_H
 
-#include "os.h"
+#include "common/common_pch.h"
 
-#include "common.h"
-#include "pr_generic.h"
-#include "vc1_common.h"
+#include "merge/pr_generic.h"
+#include "common/vc1.h"
 
 class vc1_video_packetizer_c: public generic_packetizer_c {
 protected:
@@ -40,7 +39,7 @@ public:
     return "video";
   };
 
-  virtual connection_result_e can_connect_to(generic_packetizer_c *src, string &error_message);
+  virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
 
 protected:
   virtual void flush_frames();
