@@ -11,12 +11,11 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "common/os.h"
+#include "common/common_pch.h"
 
 #include <ogg/ogg.h>
 #include <vorbis/codec.h>
 
-#include "common/common.h"
 #include "common/matroska.h"
 #include "merge/output_control.h"
 #include "output/p_vorbis.h"
